pub enum UnaryFunc<E = MirScalarExpr> {
Show 335 variants
Not(Not),
IsNull(IsNull),
IsTrue(IsTrue),
IsFalse(IsFalse),
BitNotInt16(BitNotInt16),
BitNotInt32(BitNotInt32),
BitNotInt64(BitNotInt64),
BitNotUint16(BitNotUint16),
BitNotUint32(BitNotUint32),
BitNotUint64(BitNotUint64),
NegInt16(NegInt16),
NegInt32(NegInt32),
NegInt64(NegInt64),
NegFloat32(NegFloat32),
NegFloat64(NegFloat64),
NegNumeric(NegNumeric),
NegInterval(NegInterval),
SqrtFloat64(SqrtFloat64),
SqrtNumeric(SqrtNumeric),
CbrtFloat64(CbrtFloat64),
AbsInt16(AbsInt16),
AbsInt32(AbsInt32),
AbsInt64(AbsInt64),
AbsFloat32(AbsFloat32),
AbsFloat64(AbsFloat64),
AbsNumeric(AbsNumeric),
CastBoolToString(CastBoolToString),
CastBoolToStringNonstandard(CastBoolToStringNonstandard),
CastBoolToInt32(CastBoolToInt32),
CastBoolToInt64(CastBoolToInt64),
CastInt16ToFloat32(CastInt16ToFloat32),
CastInt16ToFloat64(CastInt16ToFloat64),
CastInt16ToInt32(CastInt16ToInt32),
CastInt16ToInt64(CastInt16ToInt64),
CastInt16ToUint16(CastInt16ToUint16),
CastInt16ToUint32(CastInt16ToUint32),
CastInt16ToUint64(CastInt16ToUint64),
CastInt16ToString(CastInt16ToString),
CastInt2VectorToArray(CastInt2VectorToArray),
CastInt32ToBool(CastInt32ToBool),
CastInt32ToFloat32(CastInt32ToFloat32),
CastInt32ToFloat64(CastInt32ToFloat64),
CastInt32ToOid(CastInt32ToOid),
CastInt32ToPgLegacyChar(CastInt32ToPgLegacyChar),
CastInt32ToInt16(CastInt32ToInt16),
CastInt32ToInt64(CastInt32ToInt64),
CastInt32ToUint16(CastInt32ToUint16),
CastInt32ToUint32(CastInt32ToUint32),
CastInt32ToUint64(CastInt32ToUint64),
CastInt32ToString(CastInt32ToString),
CastOidToInt32(CastOidToInt32),
CastOidToInt64(CastOidToInt64),
CastOidToString(CastOidToString),
CastOidToRegClass(CastOidToRegClass),
CastRegClassToOid(CastRegClassToOid),
CastOidToRegProc(CastOidToRegProc),
CastRegProcToOid(CastRegProcToOid),
CastOidToRegType(CastOidToRegType),
CastRegTypeToOid(CastRegTypeToOid),
CastInt64ToInt16(CastInt64ToInt16),
CastInt64ToInt32(CastInt64ToInt32),
CastInt64ToUint16(CastInt64ToUint16),
CastInt64ToUint32(CastInt64ToUint32),
CastInt64ToUint64(CastInt64ToUint64),
CastInt16ToNumeric(CastInt16ToNumeric),
CastInt32ToNumeric(CastInt32ToNumeric),
CastInt64ToBool(CastInt64ToBool),
CastInt64ToNumeric(CastInt64ToNumeric),
CastInt64ToFloat32(CastInt64ToFloat32),
CastInt64ToFloat64(CastInt64ToFloat64),
CastInt64ToOid(CastInt64ToOid),
CastInt64ToString(CastInt64ToString),
CastUint16ToUint32(CastUint16ToUint32),
CastUint16ToUint64(CastUint16ToUint64),
CastUint16ToInt16(CastUint16ToInt16),
CastUint16ToInt32(CastUint16ToInt32),
CastUint16ToInt64(CastUint16ToInt64),
CastUint16ToNumeric(CastUint16ToNumeric),
CastUint16ToFloat32(CastUint16ToFloat32),
CastUint16ToFloat64(CastUint16ToFloat64),
CastUint16ToString(CastUint16ToString),
CastUint32ToUint16(CastUint32ToUint16),
CastUint32ToUint64(CastUint32ToUint64),
CastUint32ToInt16(CastUint32ToInt16),
CastUint32ToInt32(CastUint32ToInt32),
CastUint32ToInt64(CastUint32ToInt64),
CastUint32ToNumeric(CastUint32ToNumeric),
CastUint32ToFloat32(CastUint32ToFloat32),
CastUint32ToFloat64(CastUint32ToFloat64),
CastUint32ToString(CastUint32ToString),
CastUint64ToUint16(CastUint64ToUint16),
CastUint64ToUint32(CastUint64ToUint32),
CastUint64ToInt16(CastUint64ToInt16),
CastUint64ToInt32(CastUint64ToInt32),
CastUint64ToInt64(CastUint64ToInt64),
CastUint64ToNumeric(CastUint64ToNumeric),
CastUint64ToFloat32(CastUint64ToFloat32),
CastUint64ToFloat64(CastUint64ToFloat64),
CastUint64ToString(CastUint64ToString),
CastFloat32ToInt16(CastFloat32ToInt16),
CastFloat32ToInt32(CastFloat32ToInt32),
CastFloat32ToInt64(CastFloat32ToInt64),
CastFloat32ToUint16(CastFloat32ToUint16),
CastFloat32ToUint32(CastFloat32ToUint32),
CastFloat32ToUint64(CastFloat32ToUint64),
CastFloat32ToFloat64(CastFloat32ToFloat64),
CastFloat32ToString(CastFloat32ToString),
CastFloat32ToNumeric(CastFloat32ToNumeric),
CastFloat64ToNumeric(CastFloat64ToNumeric),
CastFloat64ToInt16(CastFloat64ToInt16),
CastFloat64ToInt32(CastFloat64ToInt32),
CastFloat64ToInt64(CastFloat64ToInt64),
CastFloat64ToUint16(CastFloat64ToUint16),
CastFloat64ToUint32(CastFloat64ToUint32),
CastFloat64ToUint64(CastFloat64ToUint64),
CastFloat64ToFloat32(CastFloat64ToFloat32),
CastFloat64ToString(CastFloat64ToString),
CastNumericToFloat32(CastNumericToFloat32),
CastNumericToFloat64(CastNumericToFloat64),
CastNumericToInt16(CastNumericToInt16),
CastNumericToInt32(CastNumericToInt32),
CastNumericToInt64(CastNumericToInt64),
CastNumericToUint16(CastNumericToUint16),
CastNumericToUint32(CastNumericToUint32),
CastNumericToUint64(CastNumericToUint64),
CastNumericToString(CastNumericToString),
CastMzTimestampToString(CastMzTimestampToString),
CastMzTimestampToTimestamp(CastMzTimestampToTimestamp),
CastMzTimestampToTimestampTz(CastMzTimestampToTimestampTz),
CastStringToMzTimestamp(CastStringToMzTimestamp),
CastUint64ToMzTimestamp(CastUint64ToMzTimestamp),
CastUint32ToMzTimestamp(CastUint32ToMzTimestamp),
CastInt64ToMzTimestamp(CastInt64ToMzTimestamp),
CastInt32ToMzTimestamp(CastInt32ToMzTimestamp),
CastNumericToMzTimestamp(CastNumericToMzTimestamp),
CastTimestampToMzTimestamp(CastTimestampToMzTimestamp),
CastTimestampTzToMzTimestamp(CastTimestampTzToMzTimestamp),
CastDateToMzTimestamp(CastDateToMzTimestamp),
CastStringToBool(CastStringToBool),
CastStringToPgLegacyChar(CastStringToPgLegacyChar),
CastStringToPgLegacyName(CastStringToPgLegacyName),
CastStringToBytes(CastStringToBytes),
CastStringToInt16(CastStringToInt16),
CastStringToInt32(CastStringToInt32),
CastStringToInt64(CastStringToInt64),
CastStringToUint16(CastStringToUint16),
CastStringToUint32(CastStringToUint32),
CastStringToUint64(CastStringToUint64),
CastStringToInt2Vector(CastStringToInt2Vector),
CastStringToOid(CastStringToOid),
CastStringToFloat32(CastStringToFloat32),
CastStringToFloat64(CastStringToFloat64),
CastStringToDate(CastStringToDate),
CastStringToArray(CastStringToArray<E>),
CastStringToList(CastStringToList<E>),
CastStringToMap(CastStringToMap<E>),
CastStringToRange(CastStringToRange<E>),
CastStringToTime(CastStringToTime),
CastStringToTimestamp(CastStringToTimestamp),
CastStringToTimestampTz(CastStringToTimestampTz),
CastStringToInterval(CastStringToInterval),
CastStringToNumeric(CastStringToNumeric),
CastStringToUuid(CastStringToUuid),
CastStringToChar(CastStringToChar),
PadChar(PadChar),
CastStringToVarChar(CastStringToVarChar),
CastCharToString(CastCharToString),
CastVarCharToString(CastVarCharToString),
CastDateToTimestamp(CastDateToTimestamp),
CastDateToTimestampTz(CastDateToTimestampTz),
CastDateToString(CastDateToString),
CastTimeToInterval(CastTimeToInterval),
CastTimeToString(CastTimeToString),
CastIntervalToString(CastIntervalToString),
CastIntervalToTime(CastIntervalToTime),
CastTimestampToDate(CastTimestampToDate),
AdjustTimestampPrecision(AdjustTimestampPrecision),
CastTimestampToTimestampTz(CastTimestampToTimestampTz),
CastTimestampToString(CastTimestampToString),
CastTimestampToTime(CastTimestampToTime),
CastTimestampTzToDate(CastTimestampTzToDate),
CastTimestampTzToTimestamp(CastTimestampTzToTimestamp),
AdjustTimestampTzPrecision(AdjustTimestampTzPrecision),
CastTimestampTzToString(CastTimestampTzToString),
CastTimestampTzToTime(CastTimestampTzToTime),
CastPgLegacyCharToString(CastPgLegacyCharToString),
CastPgLegacyCharToChar(CastPgLegacyCharToChar),
CastPgLegacyCharToVarChar(CastPgLegacyCharToVarChar),
CastPgLegacyCharToInt32(CastPgLegacyCharToInt32),
CastBytesToString(CastBytesToString),
CastStringToJsonb(CastStringToJsonb),
CastJsonbToString(CastJsonbToString),
CastJsonbableToJsonb(CastJsonbableToJsonb),
CastJsonbToInt16(CastJsonbToInt16),
CastJsonbToInt32(CastJsonbToInt32),
CastJsonbToInt64(CastJsonbToInt64),
CastJsonbToFloat32(CastJsonbToFloat32),
CastJsonbToFloat64(CastJsonbToFloat64),
CastJsonbToNumeric(CastJsonbToNumeric),
CastJsonbToBool(CastJsonbToBool),
CastUuidToString(CastUuidToString),
CastRecordToString(CastRecordToString),
CastRecord1ToRecord2(CastRecord1ToRecord2<E>),
CastArrayToArray(CastArrayToArray<E>),
CastArrayToJsonb(CastArrayToJsonb<E>),
CastArrayToString(CastArrayToString),
CastListToString(CastListToString),
CastListToJsonb(CastListToJsonb<E>),
CastList1ToList2(CastList1ToList2<E>),
CastArrayToListOneDim(CastArrayToListOneDim),
CastMapToString(CastMapToString),
CastInt2VectorToString(CastInt2VectorToString),
CastRangeToString(CastRangeToString),
CeilFloat32(CeilFloat32),
CeilFloat64(CeilFloat64),
CeilNumeric(CeilNumeric),
FloorFloat32(FloorFloat32),
FloorFloat64(FloorFloat64),
FloorNumeric(FloorNumeric),
Ascii(Ascii),
BitCountBytes(BitCountBytes),
BitLengthBytes(BitLengthBytes),
BitLengthString(BitLengthString),
ByteLengthBytes(ByteLengthBytes),
ByteLengthString(ByteLengthString),
CharLength(CharLength),
Chr(Chr),
IsLikeMatch(IsLikeMatch),
IsRegexpMatch(IsRegexpMatch),
RegexpMatch(RegexpMatch),
ExtractInterval(ExtractInterval),
ExtractTime(ExtractTime),
ExtractTimestamp(ExtractTimestamp),
ExtractTimestampTz(ExtractTimestampTz),
ExtractDate(ExtractDate),
DatePartInterval(DatePartInterval),
DatePartTime(DatePartTime),
DatePartTimestamp(DatePartTimestamp),
DatePartTimestampTz(DatePartTimestampTz),
DateTruncTimestamp(DateTruncTimestamp),
DateTruncTimestampTz(DateTruncTimestampTz),
TimezoneTimestamp(TimezoneTimestamp),
TimezoneTimestampTz(TimezoneTimestampTz),
TimezoneTime(TimezoneTime),
ToTimestamp(ToTimestamp),
ToCharTimestamp(ToCharTimestamp),
ToCharTimestampTz(ToCharTimestampTz),
JustifyDays(JustifyDays),
JustifyHours(JustifyHours),
JustifyInterval(JustifyInterval),
JsonbArrayLength(JsonbArrayLength),
JsonbTypeof(JsonbTypeof),
JsonbStripNulls(JsonbStripNulls),
JsonbPretty(JsonbPretty),
ParseCatalogAclMode(ParseCatalogAclMode),
ParseCatalogAuditLogDetails(ParseCatalogAuditLogDetails),
ParseCatalogCreateSql(ParseCatalogCreateSql),
ParseCatalogId(ParseCatalogId),
ParseCatalogPrivileges(ParseCatalogPrivileges),
ParseConnectionDetails(ParseConnectionDetails),
ParseKafkaSourceDetails(ParseKafkaSourceDetails),
ParsePostgresSourceDetails(ParsePostgresSourceDetails),
ParseSourceExportDetails(ParseSourceExportDetails),
RedactSql(RedactSql),
RoundFloat32(RoundFloat32),
RoundFloat64(RoundFloat64),
RoundNumeric(RoundNumeric),
TruncFloat32(TruncFloat32),
TruncFloat64(TruncFloat64),
TruncNumeric(TruncNumeric),
TrimWhitespace(TrimWhitespace),
TrimLeadingWhitespace(TrimLeadingWhitespace),
TrimTrailingWhitespace(TrimTrailingWhitespace),
Initcap(Initcap),
RecordGet(RecordGet),
ListLength(ListLength),
MapLength(MapLength),
MapBuildFromRecordList(MapBuildFromRecordList),
Upper(Upper),
Lower(Lower),
Cos(Cos),
Acos(Acos),
Cosh(Cosh),
Acosh(Acosh),
Sin(Sin),
Asin(Asin),
Sinh(Sinh),
Asinh(Asinh),
Tan(Tan),
Atan(Atan),
Tanh(Tanh),
Atanh(Atanh),
Cot(Cot),
Degrees(Degrees),
Radians(Radians),
Log10(Log10),
Log10Numeric(Log10Numeric),
Ln(Ln),
LnNumeric(LnNumeric),
Exp(Exp),
ExpNumeric(ExpNumeric),
Sleep(Sleep),
Panic(Panic),
AdjustNumericScale(AdjustNumericScale),
PgColumnSize(PgColumnSize),
MzRowSize(MzRowSize),
MzTypeName(MzTypeName),
StepMzTimestamp(StepMzTimestamp),
RangeLower(RangeLower),
RangeUpper(RangeUpper),
RangeEmpty(RangeEmpty),
RangeLowerInc(RangeLowerInc),
RangeUpperInc(RangeUpperInc),
RangeLowerInf(RangeLowerInf),
RangeUpperInf(RangeUpperInf),
MzAclItemGrantor(MzAclItemGrantor),
MzAclItemGrantee(MzAclItemGrantee),
MzAclItemPrivileges(MzAclItemPrivileges),
MzFormatPrivileges(MzFormatPrivileges),
MzValidatePrivileges(MzValidatePrivileges),
MzValidateRolePrivilege(MzValidateRolePrivilege),
AclItemGrantor(AclItemGrantor),
AclItemGrantee(AclItemGrantee),
AclItemPrivileges(AclItemPrivileges),
QuoteIdent(QuoteIdent),
TryParseMonotonicIso8601Timestamp(TryParseMonotonicIso8601Timestamp),
RegexpSplitToArray(RegexpSplitToArray),
PgSizePretty(PgSizePretty),
Crc32Bytes(Crc32Bytes),
Crc32String(Crc32String),
KafkaMurmur2Bytes(KafkaMurmur2Bytes),
KafkaMurmur2String(KafkaMurmur2String),
SeahashBytes(SeahashBytes),
SeahashString(SeahashString),
Reverse(Reverse),
}Variants
Not(Not)
IsNull(IsNull)
IsTrue(IsTrue)
IsFalse(IsFalse)
BitNotInt16(BitNotInt16)
BitNotInt32(BitNotInt32)
BitNotInt64(BitNotInt64)
BitNotUint16(BitNotUint16)
BitNotUint32(BitNotUint32)
BitNotUint64(BitNotUint64)
NegInt16(NegInt16)
NegInt32(NegInt32)
NegInt64(NegInt64)
NegFloat32(NegFloat32)
NegFloat64(NegFloat64)
NegNumeric(NegNumeric)
NegInterval(NegInterval)
SqrtFloat64(SqrtFloat64)
SqrtNumeric(SqrtNumeric)
CbrtFloat64(CbrtFloat64)
AbsInt16(AbsInt16)
AbsInt32(AbsInt32)
AbsInt64(AbsInt64)
AbsFloat32(AbsFloat32)
AbsFloat64(AbsFloat64)
AbsNumeric(AbsNumeric)
CastBoolToString(CastBoolToString)
CastBoolToStringNonstandard(CastBoolToStringNonstandard)
CastBoolToInt32(CastBoolToInt32)
CastBoolToInt64(CastBoolToInt64)
CastInt16ToFloat32(CastInt16ToFloat32)
CastInt16ToFloat64(CastInt16ToFloat64)
CastInt16ToInt32(CastInt16ToInt32)
CastInt16ToInt64(CastInt16ToInt64)
CastInt16ToUint16(CastInt16ToUint16)
CastInt16ToUint32(CastInt16ToUint32)
CastInt16ToUint64(CastInt16ToUint64)
CastInt16ToString(CastInt16ToString)
CastInt2VectorToArray(CastInt2VectorToArray)
CastInt32ToBool(CastInt32ToBool)
CastInt32ToFloat32(CastInt32ToFloat32)
CastInt32ToFloat64(CastInt32ToFloat64)
CastInt32ToOid(CastInt32ToOid)
CastInt32ToPgLegacyChar(CastInt32ToPgLegacyChar)
CastInt32ToInt16(CastInt32ToInt16)
CastInt32ToInt64(CastInt32ToInt64)
CastInt32ToUint16(CastInt32ToUint16)
CastInt32ToUint32(CastInt32ToUint32)
CastInt32ToUint64(CastInt32ToUint64)
CastInt32ToString(CastInt32ToString)
CastOidToInt32(CastOidToInt32)
CastOidToInt64(CastOidToInt64)
CastOidToString(CastOidToString)
CastOidToRegClass(CastOidToRegClass)
CastRegClassToOid(CastRegClassToOid)
CastOidToRegProc(CastOidToRegProc)
CastRegProcToOid(CastRegProcToOid)
CastOidToRegType(CastOidToRegType)
CastRegTypeToOid(CastRegTypeToOid)
CastInt64ToInt16(CastInt64ToInt16)
CastInt64ToInt32(CastInt64ToInt32)
CastInt64ToUint16(CastInt64ToUint16)
CastInt64ToUint32(CastInt64ToUint32)
CastInt64ToUint64(CastInt64ToUint64)
CastInt16ToNumeric(CastInt16ToNumeric)
CastInt32ToNumeric(CastInt32ToNumeric)
CastInt64ToBool(CastInt64ToBool)
CastInt64ToNumeric(CastInt64ToNumeric)
CastInt64ToFloat32(CastInt64ToFloat32)
CastInt64ToFloat64(CastInt64ToFloat64)
CastInt64ToOid(CastInt64ToOid)
CastInt64ToString(CastInt64ToString)
CastUint16ToUint32(CastUint16ToUint32)
CastUint16ToUint64(CastUint16ToUint64)
CastUint16ToInt16(CastUint16ToInt16)
CastUint16ToInt32(CastUint16ToInt32)
CastUint16ToInt64(CastUint16ToInt64)
CastUint16ToNumeric(CastUint16ToNumeric)
CastUint16ToFloat32(CastUint16ToFloat32)
CastUint16ToFloat64(CastUint16ToFloat64)
CastUint16ToString(CastUint16ToString)
CastUint32ToUint16(CastUint32ToUint16)
CastUint32ToUint64(CastUint32ToUint64)
CastUint32ToInt16(CastUint32ToInt16)
CastUint32ToInt32(CastUint32ToInt32)
CastUint32ToInt64(CastUint32ToInt64)
CastUint32ToNumeric(CastUint32ToNumeric)
CastUint32ToFloat32(CastUint32ToFloat32)
CastUint32ToFloat64(CastUint32ToFloat64)
CastUint32ToString(CastUint32ToString)
CastUint64ToUint16(CastUint64ToUint16)
CastUint64ToUint32(CastUint64ToUint32)
CastUint64ToInt16(CastUint64ToInt16)
CastUint64ToInt32(CastUint64ToInt32)
CastUint64ToInt64(CastUint64ToInt64)
CastUint64ToNumeric(CastUint64ToNumeric)
CastUint64ToFloat32(CastUint64ToFloat32)
CastUint64ToFloat64(CastUint64ToFloat64)
CastUint64ToString(CastUint64ToString)
CastFloat32ToInt16(CastFloat32ToInt16)
CastFloat32ToInt32(CastFloat32ToInt32)
CastFloat32ToInt64(CastFloat32ToInt64)
CastFloat32ToUint16(CastFloat32ToUint16)
CastFloat32ToUint32(CastFloat32ToUint32)
CastFloat32ToUint64(CastFloat32ToUint64)
CastFloat32ToFloat64(CastFloat32ToFloat64)
CastFloat32ToString(CastFloat32ToString)
CastFloat32ToNumeric(CastFloat32ToNumeric)
CastFloat64ToNumeric(CastFloat64ToNumeric)
CastFloat64ToInt16(CastFloat64ToInt16)
CastFloat64ToInt32(CastFloat64ToInt32)
CastFloat64ToInt64(CastFloat64ToInt64)
CastFloat64ToUint16(CastFloat64ToUint16)
CastFloat64ToUint32(CastFloat64ToUint32)
CastFloat64ToUint64(CastFloat64ToUint64)
CastFloat64ToFloat32(CastFloat64ToFloat32)
CastFloat64ToString(CastFloat64ToString)
CastNumericToFloat32(CastNumericToFloat32)
CastNumericToFloat64(CastNumericToFloat64)
CastNumericToInt16(CastNumericToInt16)
CastNumericToInt32(CastNumericToInt32)
CastNumericToInt64(CastNumericToInt64)
CastNumericToUint16(CastNumericToUint16)
CastNumericToUint32(CastNumericToUint32)
CastNumericToUint64(CastNumericToUint64)
CastNumericToString(CastNumericToString)
CastMzTimestampToString(CastMzTimestampToString)
CastMzTimestampToTimestamp(CastMzTimestampToTimestamp)
CastMzTimestampToTimestampTz(CastMzTimestampToTimestampTz)
CastStringToMzTimestamp(CastStringToMzTimestamp)
CastUint64ToMzTimestamp(CastUint64ToMzTimestamp)
CastUint32ToMzTimestamp(CastUint32ToMzTimestamp)
CastInt64ToMzTimestamp(CastInt64ToMzTimestamp)
CastInt32ToMzTimestamp(CastInt32ToMzTimestamp)
CastNumericToMzTimestamp(CastNumericToMzTimestamp)
CastTimestampToMzTimestamp(CastTimestampToMzTimestamp)
CastTimestampTzToMzTimestamp(CastTimestampTzToMzTimestamp)
CastDateToMzTimestamp(CastDateToMzTimestamp)
CastStringToBool(CastStringToBool)
CastStringToPgLegacyChar(CastStringToPgLegacyChar)
CastStringToPgLegacyName(CastStringToPgLegacyName)
CastStringToBytes(CastStringToBytes)
CastStringToInt16(CastStringToInt16)
CastStringToInt32(CastStringToInt32)
CastStringToInt64(CastStringToInt64)
CastStringToUint16(CastStringToUint16)
CastStringToUint32(CastStringToUint32)
CastStringToUint64(CastStringToUint64)
CastStringToInt2Vector(CastStringToInt2Vector)
CastStringToOid(CastStringToOid)
CastStringToFloat32(CastStringToFloat32)
CastStringToFloat64(CastStringToFloat64)
CastStringToDate(CastStringToDate)
CastStringToArray(CastStringToArray<E>)
CastStringToList(CastStringToList<E>)
CastStringToMap(CastStringToMap<E>)
CastStringToRange(CastStringToRange<E>)
CastStringToTime(CastStringToTime)
CastStringToTimestamp(CastStringToTimestamp)
CastStringToTimestampTz(CastStringToTimestampTz)
CastStringToInterval(CastStringToInterval)
CastStringToNumeric(CastStringToNumeric)
CastStringToUuid(CastStringToUuid)
CastStringToChar(CastStringToChar)
PadChar(PadChar)
CastStringToVarChar(CastStringToVarChar)
CastCharToString(CastCharToString)
CastVarCharToString(CastVarCharToString)
CastDateToTimestamp(CastDateToTimestamp)
CastDateToTimestampTz(CastDateToTimestampTz)
CastDateToString(CastDateToString)
CastTimeToInterval(CastTimeToInterval)
CastTimeToString(CastTimeToString)
CastIntervalToString(CastIntervalToString)
CastIntervalToTime(CastIntervalToTime)
CastTimestampToDate(CastTimestampToDate)
AdjustTimestampPrecision(AdjustTimestampPrecision)
CastTimestampToTimestampTz(CastTimestampToTimestampTz)
CastTimestampToString(CastTimestampToString)
CastTimestampToTime(CastTimestampToTime)
CastTimestampTzToDate(CastTimestampTzToDate)
CastTimestampTzToTimestamp(CastTimestampTzToTimestamp)
AdjustTimestampTzPrecision(AdjustTimestampTzPrecision)
CastTimestampTzToString(CastTimestampTzToString)
CastTimestampTzToTime(CastTimestampTzToTime)
CastPgLegacyCharToString(CastPgLegacyCharToString)
CastPgLegacyCharToChar(CastPgLegacyCharToChar)
CastPgLegacyCharToVarChar(CastPgLegacyCharToVarChar)
CastPgLegacyCharToInt32(CastPgLegacyCharToInt32)
CastBytesToString(CastBytesToString)
CastStringToJsonb(CastStringToJsonb)
CastJsonbToString(CastJsonbToString)
CastJsonbableToJsonb(CastJsonbableToJsonb)
CastJsonbToInt16(CastJsonbToInt16)
CastJsonbToInt32(CastJsonbToInt32)
CastJsonbToInt64(CastJsonbToInt64)
CastJsonbToFloat32(CastJsonbToFloat32)
CastJsonbToFloat64(CastJsonbToFloat64)
CastJsonbToNumeric(CastJsonbToNumeric)
CastJsonbToBool(CastJsonbToBool)
CastUuidToString(CastUuidToString)
CastRecordToString(CastRecordToString)
CastRecord1ToRecord2(CastRecord1ToRecord2<E>)
CastArrayToArray(CastArrayToArray<E>)
CastArrayToJsonb(CastArrayToJsonb<E>)
CastArrayToString(CastArrayToString)
CastListToString(CastListToString)
CastListToJsonb(CastListToJsonb<E>)
CastList1ToList2(CastList1ToList2<E>)
CastArrayToListOneDim(CastArrayToListOneDim)
CastMapToString(CastMapToString)
CastInt2VectorToString(CastInt2VectorToString)
CastRangeToString(CastRangeToString)
CeilFloat32(CeilFloat32)
CeilFloat64(CeilFloat64)
CeilNumeric(CeilNumeric)
FloorFloat32(FloorFloat32)
FloorFloat64(FloorFloat64)
FloorNumeric(FloorNumeric)
Ascii(Ascii)
BitCountBytes(BitCountBytes)
BitLengthBytes(BitLengthBytes)
BitLengthString(BitLengthString)
ByteLengthBytes(ByteLengthBytes)
ByteLengthString(ByteLengthString)
CharLength(CharLength)
Chr(Chr)
IsLikeMatch(IsLikeMatch)
IsRegexpMatch(IsRegexpMatch)
RegexpMatch(RegexpMatch)
ExtractInterval(ExtractInterval)
ExtractTime(ExtractTime)
ExtractTimestamp(ExtractTimestamp)
ExtractTimestampTz(ExtractTimestampTz)
ExtractDate(ExtractDate)
DatePartInterval(DatePartInterval)
DatePartTime(DatePartTime)
DatePartTimestamp(DatePartTimestamp)
DatePartTimestampTz(DatePartTimestampTz)
DateTruncTimestamp(DateTruncTimestamp)
DateTruncTimestampTz(DateTruncTimestampTz)
TimezoneTimestamp(TimezoneTimestamp)
TimezoneTimestampTz(TimezoneTimestampTz)
TimezoneTime(TimezoneTime)
ToTimestamp(ToTimestamp)
ToCharTimestamp(ToCharTimestamp)
ToCharTimestampTz(ToCharTimestampTz)
JustifyDays(JustifyDays)
JustifyHours(JustifyHours)
JustifyInterval(JustifyInterval)
JsonbArrayLength(JsonbArrayLength)
JsonbTypeof(JsonbTypeof)
JsonbStripNulls(JsonbStripNulls)
JsonbPretty(JsonbPretty)
ParseCatalogAclMode(ParseCatalogAclMode)
ParseCatalogAuditLogDetails(ParseCatalogAuditLogDetails)
ParseCatalogCreateSql(ParseCatalogCreateSql)
ParseCatalogId(ParseCatalogId)
ParseCatalogPrivileges(ParseCatalogPrivileges)
ParseConnectionDetails(ParseConnectionDetails)
ParseKafkaSourceDetails(ParseKafkaSourceDetails)
ParsePostgresSourceDetails(ParsePostgresSourceDetails)
ParseSourceExportDetails(ParseSourceExportDetails)
RedactSql(RedactSql)
RoundFloat32(RoundFloat32)
RoundFloat64(RoundFloat64)
RoundNumeric(RoundNumeric)
TruncFloat32(TruncFloat32)
TruncFloat64(TruncFloat64)
TruncNumeric(TruncNumeric)
TrimWhitespace(TrimWhitespace)
TrimLeadingWhitespace(TrimLeadingWhitespace)
TrimTrailingWhitespace(TrimTrailingWhitespace)
Initcap(Initcap)
RecordGet(RecordGet)
ListLength(ListLength)
MapLength(MapLength)
MapBuildFromRecordList(MapBuildFromRecordList)
Upper(Upper)
Lower(Lower)
Cos(Cos)
Acos(Acos)
Cosh(Cosh)
Acosh(Acosh)
Sin(Sin)
Asin(Asin)
Sinh(Sinh)
Asinh(Asinh)
Tan(Tan)
Atan(Atan)
Tanh(Tanh)
Atanh(Atanh)
Cot(Cot)
Degrees(Degrees)
Radians(Radians)
Log10(Log10)
Log10Numeric(Log10Numeric)
Ln(Ln)
LnNumeric(LnNumeric)
Exp(Exp)
ExpNumeric(ExpNumeric)
Sleep(Sleep)
Panic(Panic)
AdjustNumericScale(AdjustNumericScale)
PgColumnSize(PgColumnSize)
MzRowSize(MzRowSize)
MzTypeName(MzTypeName)
StepMzTimestamp(StepMzTimestamp)
RangeLower(RangeLower)
RangeUpper(RangeUpper)
RangeEmpty(RangeEmpty)
RangeLowerInc(RangeLowerInc)
RangeUpperInc(RangeUpperInc)
RangeLowerInf(RangeLowerInf)
RangeUpperInf(RangeUpperInf)
MzAclItemGrantor(MzAclItemGrantor)
MzAclItemGrantee(MzAclItemGrantee)
MzAclItemPrivileges(MzAclItemPrivileges)
MzFormatPrivileges(MzFormatPrivileges)
MzValidatePrivileges(MzValidatePrivileges)
MzValidateRolePrivilege(MzValidateRolePrivilege)
AclItemGrantor(AclItemGrantor)
AclItemGrantee(AclItemGrantee)
AclItemPrivileges(AclItemPrivileges)
QuoteIdent(QuoteIdent)
TryParseMonotonicIso8601Timestamp(TryParseMonotonicIso8601Timestamp)
RegexpSplitToArray(RegexpSplitToArray)
PgSizePretty(PgSizePretty)
Crc32Bytes(Crc32Bytes)
Crc32String(Crc32String)
KafkaMurmur2Bytes(KafkaMurmur2Bytes)
KafkaMurmur2String(KafkaMurmur2String)
SeahashBytes(SeahashBytes)
SeahashString(SeahashString)
Reverse(Reverse)
Implementations
Sourceimpl<E: Eval> UnaryFunc<E>
impl<E: Eval> UnaryFunc<E>
pub fn eval<'a>( &'a self, datums: &[Datum<'a>], temp_storage: &'a RowArena, a: &'a impl Eval, ) -> Result<Datum<'a>, EvalError>
pub fn output_sql_type(&self, input_type: SqlColumnType) -> SqlColumnType
pub fn output_type(&self, input_type: ReprColumnType) -> ReprColumnType
pub fn propagates_nulls(&self) -> bool
pub fn introduces_nulls(&self) -> bool
pub fn preserves_uniqueness(&self) -> bool
pub fn is_monotone(&self) -> bool
pub fn could_error(&self) -> bool
pub fn is_eliminable_cast(&self) -> bool
Sourceimpl<E> UnaryFunc<E>
impl<E> UnaryFunc<E>
Sourcepub fn variant_name(&self) -> &'static str
pub fn variant_name(&self) -> &'static str
The canonical name of this variant, as declared by its
FuncName impl.
Sourceimpl UnaryFunc
impl UnaryFunc
pub fn inverse(&self) -> Option<UnaryFunc>
Sourcepub fn from_variant_name(name: &str) -> Option<Self>
pub fn from_variant_name(name: &str) -> Option<Self>
Attempts to construct a UnaryFunc from the canonical name of
one of its variants, as declared by the variant’s
FuncName impl (the name of the
underlying Rust function, e.g. cast_int32_to_numeric).
Intended for test tooling that needs to name exact function
variants. Only variants whose inner function deserializes from
no data (unit functions and functions all of whose parameters
may default to None) are constructible. Returns None for
other variants and for unknown names. Returns the MIR
instantiation.
Sourcepub fn variant_names() -> impl Iterator<Item = &'static str>
pub fn variant_names() -> impl Iterator<Item = &'static str>
The canonical names of all variants, in declaration order.