pub trait HumanizeDisplay: Sized {
// Required method
fn humanize<'a, M: HumanizerMode>(
e: &HumanizedExpr<'a, Self, M>,
f: &mut Formatter<'_>,
) -> Result;
}Required Methods
fn humanize<'a, M: HumanizerMode>( e: &HumanizedExpr<'a, Self, M>, f: &mut Formatter<'_>, ) -> Result
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl HumanizeDisplay for StableRow
Delegates to the Row rendering of the wrapped row.
impl HumanizeDisplay for StableRow
Delegates to the Row rendering of the wrapped row.