pub struct FuncRegistry {
pub unary: BTreeMap<String, Record<UnaryFuncProperties>>,
pub binary: BTreeMap<String, Record<BinaryFuncProperties>>,
pub variadic: BTreeMap<String, Record<VariadicFuncProperties>>,
}Expand description
Fields
unary: BTreeMap<String, Record<UnaryFuncProperties>>binary: BTreeMap<String, Record<BinaryFuncProperties>>variadic: BTreeMap<String, Record<VariadicFuncProperties>>Implementations
Sourceimpl FuncRegistry
impl FuncRegistry
Sourcepub fn build() -> FuncRegistry
pub fn build() -> FuncRegistry
Records the properties of every variant of the three function enums.
Panics if a variant can neither be constructed from its canonical name
nor has a Sample in this module, or if a sample’s input count does
not fit its function.