pub struct CastArrayToJsonb<E = MirScalarExpr> {
pub cast_element: Box<E>,
}Fields
cast_element: Box<E>Implementations
Sourceimpl<E> CastArrayToJsonb<E>
impl<E> CastArrayToJsonb<E>
Sourcepub fn try_map_expr<'a, E2: TryFrom<&'a E>>(
&'a self,
) -> Result<CastArrayToJsonb<E2>, E2::Error>
pub fn try_map_expr<'a, E2: TryFrom<&'a E>>( &'a self, ) -> Result<CastArrayToJsonb<E2>, E2::Error>
Rebuilds this function with the element cast expression converted to
E2.
Sourcepub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastArrayToJsonb<E2>
pub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastArrayToJsonb<E2>
Rebuilds this function with the element cast expression converted to
E2.