pub struct CastList1ToList2<E = MirScalarExpr> {
pub return_ty: SqlScalarType,
pub cast_expr: Box<E>,
}Expand description
Casts between two list types by casting each element of a (“list1”) using
cast_expr and collecting the results into a new list (“list2”).
Fields
return_ty: SqlScalarTypeList2’s type
cast_expr: Box<E>The expression to cast List1’s elements to List2’s elements’ type
Implementations
Sourceimpl<E> CastList1ToList2<E>
impl<E> CastList1ToList2<E>
Sourcepub fn try_map_expr<'a, E2: TryFrom<&'a E>>(
&'a self,
) -> Result<CastList1ToList2<E2>, E2::Error>
pub fn try_map_expr<'a, E2: TryFrom<&'a E>>( &'a self, ) -> Result<CastList1ToList2<E2>, E2::Error>
Rebuilds this function with the element cast expression converted to
E2.
Sourcepub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastList1ToList2<E2>
pub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastList1ToList2<E2>
Rebuilds this function with the element cast expression converted to
E2.