pub struct CastRecord1ToRecord2<E = MirScalarExpr> {
pub return_ty: SqlScalarType,
pub cast_exprs: Box<[E]>,
}Expand description
Casts between two record types by casting each element of a (“record1”) using
cast_expr and collecting the results into a new record (“record2”).
Fields
return_ty: SqlScalarTypecast_exprs: Box<[E]>Implementations
Sourceimpl<E> CastRecord1ToRecord2<E>
impl<E> CastRecord1ToRecord2<E>
Sourcepub fn try_map_expr<'a, E2: TryFrom<&'a E>>(
&'a self,
) -> Result<CastRecord1ToRecord2<E2>, E2::Error>
pub fn try_map_expr<'a, E2: TryFrom<&'a E>>( &'a self, ) -> Result<CastRecord1ToRecord2<E2>, E2::Error>
Rebuilds this function with the field cast expressions converted to
E2. Reports the first failing field, not all of them. Callers treat
any failure as a lowering bug.
Sourcepub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastRecord1ToRecord2<E2>
pub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastRecord1ToRecord2<E2>
Rebuilds this function with the field cast expressions converted to
E2.