pub struct CastStringToMap<E = MirScalarExpr> {
pub return_ty: SqlScalarType,
pub cast_expr: Box<E>,
}Fields
return_ty: SqlScalarTypecast_expr: Box<E>Implementations
Sourceimpl<E> CastStringToMap<E>
impl<E> CastStringToMap<E>
Sourcepub fn try_map_expr<'a, E2: TryFrom<&'a E>>(
&'a self,
) -> Result<CastStringToMap<E2>, E2::Error>
pub fn try_map_expr<'a, E2: TryFrom<&'a E>>( &'a self, ) -> Result<CastStringToMap<E2>, E2::Error>
Rebuilds this function with the element cast expression converted to
E2.
Sourcepub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastStringToMap<E2>
pub fn map_expr<'a, E2: From<&'a E>>(&'a self) -> CastStringToMap<E2>
Rebuilds this function with the element cast expression converted to
E2.