pub struct RowCollection {
encoded: Bytes,
metadata: Arc<[EncodedRowMetadata]>,
}Expand description
Fields
encoded: BytesContiguous blob of encoded Rows.
metadata: Arc<[EncodedRowMetadata]>Metadata about an individual Row in the blob.
Implementations
Sourceimpl RowCollection
impl RowCollection
Sourcepub fn new(rows: Vec<(Row, NonZeroUsize)>, order_by: &[ColumnOrder]) -> Self
pub fn new(rows: Vec<(Row, NonZeroUsize)>, order_by: &[ColumnOrder]) -> Self
Create a new RowCollection from a collection of Rows. Sorts data by order_by.
Note that all row collections to be merged must be constructed with the same order_by
to ensure a consistent sort order. Anything else is undefined behavior.
Sourcepub fn concat(&mut self, other: &RowCollection)
pub fn concat(&mut self, other: &RowCollection)
Concatenate another RowCollection onto self, copying and reallocating both sets of rows.
This does not reorder the rows; the output will be sorted only if the inputs are.
Sourcepub fn offset_limit(total: usize, offset: usize, limit: Option<usize>) -> usize
pub fn offset_limit(total: usize, offset: usize, limit: Option<usize>) -> usize
Adjust a row count for the provided offset and limit.
This is only marginally related to row collections, but many callers need to make this adjustment.
Sourcepub fn entries(&self) -> usize
pub fn entries(&self) -> usize
Total count of (Row, EncodedRowMetadata) pairs in this collection.
Sourcepub fn byte_len(&self) -> usize
pub fn byte_len(&self) -> usize
Returns the number of bytes this RowCollection uses.
Sourcepub fn get(&self, idx: usize) -> Option<(&RowRef, &EncodedRowMetadata)>
pub fn get(&self, idx: usize) -> Option<(&RowRef, &EncodedRowMetadata)>
Returns a RowRef for the entry at idx, if one exists.
Sourcepub fn merge_sorted(runs: &[Self], order_by: &[ColumnOrder]) -> RowCollection
pub fn merge_sorted(runs: &[Self], order_by: &[ColumnOrder]) -> RowCollection
“Sorts” the RowCollection by the column order in order_by. The output will be sorted
if the inputs were all sorted by the given order; otherwise, the order is unspecified.
In either case, the output will be a RowCollection that contains the full contents of all
the input collections.
fn merge_sorted_inner<F>(runs: &[Self], cmp: &F) -> RowCollection