pub struct RowCollectionIter {
collection: RowCollection,
row_idx: usize,
diff_idx: usize,
limit: Option<usize>,
offset: usize,
projection: Option<Vec<usize>>,
projection_buf: (DatumVec, Row),
}Fields
collection: RowCollectionCollection we’re iterating over.
row_idx: usizeIndex for the row we’re currently referencing.
diff_idx: usizeNumber of diffs we’ve emitted for the current row.
limit: Option<usize>Maximum number of rows this iterator will yield.
offset: usizeNumber of rows we’re offset by.
Note: We eagerly apply an offset, but we track it here so we can
accurately report RowIterator::count.
projection: Option<Vec<usize>>Columns to underlying rows to include.
projection_buf: (DatumVec, Row)Allocations that we reuse for every iteration to project columns.
Implementations
Sourceimpl RowCollectionIter
impl RowCollectionIter
Sourcepub fn into_inner(self) -> RowCollection
pub fn into_inner(self) -> RowCollection
Returns the inner RowCollection.
Sourcepub fn apply_offset(self, offset: usize) -> RowCollectionIter
pub fn apply_offset(self, offset: usize) -> RowCollectionIter
Immediately applies an offset to this iterator.
Sourcepub fn with_limit(self, limit: usize) -> RowCollectionIter
pub fn with_limit(self, limit: usize) -> RowCollectionIter
Sets the limit for this iterator.
Sourcepub fn with_projection(self, projection: Vec<usize>) -> RowCollectionIter
pub fn with_projection(self, projection: Vec<usize>) -> RowCollectionIter
Specify the columns that should be yielded.
Sourcefn advance_by(
collection: &RowCollection,
row_idx: &mut usize,
diff_idx: &mut usize,
count: usize,
)
fn advance_by( collection: &RowCollection, row_idx: &mut usize, diff_idx: &mut usize, count: usize, )
Helper method for implementing RowIterator.
Advances the internal pointers by the specified amount.