derive_variadic

Macro derive_variadic 

macro_rules! derive_variadic {
    ($($name:ident ( $variant:ident )),* $(,)?) => { ... };
}
Generates the VariadicFunc enum, its impl block, Display impl, and From<InnerType> impls for each variant.

All variants must use explicit Name(Type) syntax. When the variant name equals the inner type name, write e.g. And(And).