fn precompile_to_char<F>(e: &mut MirScalarExpr, build_unary: F)Expand description
Specializes a to_char_* binary call whose format-string argument is a
literal, by compiling the format into the unary form.
fn precompile_to_char<F>(e: &mut MirScalarExpr, build_unary: F)Specializes a to_char_* binary call whose format-string argument is a
literal, by compiling the format into the unary form.