reduce

Function reduce 

pub fn reduce(expr: &mut MirScalarExpr, column_types: &[ReprColumnType])
Reduce expr to a simpler equivalent form by repeatedly applying local rewrite rules until reaching a fixed point.