pub struct ColumnSpecs<'a> {
pub relation: &'a ReprRelationType,
pub columns: Vec<ResultSpec<'a>>,
pub unmaterializables: BTreeMap<UnmaterializableFunc, ResultSpec<'a>>,
pub arena: &'a RowArena,
}Expand description
An interpreter that:
- stores both the type and the range of possible values for every column and
unmaterializable function. (See the
push_methods.) - given an expression (or MFP, etc.), returns the range of possible results that evaluating that
expression might have. (See the
eval_methods.)
Fields
relation: &'a ReprRelationTypecolumns: Vec<ResultSpec<'a>>unmaterializables: BTreeMap<UnmaterializableFunc, ResultSpec<'a>>arena: &'a RowArenaImplementations
Sourceimpl<'a> ColumnSpecs<'a>
impl<'a> ColumnSpecs<'a>
Sourcepub fn new(relation: &'a ReprRelationType, arena: &'a RowArena) -> Self
pub fn new(relation: &'a ReprRelationType, arena: &'a RowArena) -> Self
Create a new, empty set of column specs. (Initially, the only assumption we make about the data in the column is that it matches the type.)
Sourcepub fn push_column(&mut self, id: usize, update: ResultSpec<'a>)
pub fn push_column(&mut self, id: usize, update: ResultSpec<'a>)
Restrict the set of possible values in a given column. (By intersecting it with the existing spec.)
Sourcepub fn push_unmaterializable(
&mut self,
func: UnmaterializableFunc,
update: ResultSpec<'a>,
)
pub fn push_unmaterializable( &mut self, func: UnmaterializableFunc, update: ResultSpec<'a>, )
Restrict the set of possible values a given unmaterializable func might return. (By intersecting it with the existing spec.)