FuncName

Trait FuncName 

pub trait FuncName {
    const NAME: &'static str;
}
The canonical name of a scalar function.

For functions generated by #[sqlfunc] this is the name of the underlying Rust function. Hand-written functions declare it explicitly. Test tooling refers to exact function variants by these names, via UnaryFunc::from_variant_name and its binary and variadic counterparts.

Required Associated Constants

const NAME: &'static str

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl FuncName for AbsFloat32

Source

const NAME: &'static str = "abs_float32"

Source

impl FuncName for AbsFloat64

Source

const NAME: &'static str = "abs_float64"

Source

impl FuncName for AbsInt16

Source

const NAME: &'static str = "abs_int16"

Source

impl FuncName for AbsInt32

Source

const NAME: &'static str = "abs_int32"

Source

impl FuncName for AbsInt64

Source

const NAME: &'static str = "abs_int64"

Source

impl FuncName for AbsNumeric

Source

const NAME: &'static str = "abs_numeric"

Source

impl FuncName for AclItemGrantee

Source

const NAME: &'static str = "acl_item_grantee"

Source

impl FuncName for AclItemGrantor

Source

const NAME: &'static str = "acl_item_grantor"

Source

impl FuncName for AclItemPrivileges

Source

const NAME: &'static str = "acl_item_privileges"

Source

impl FuncName for Acos

Source

const NAME: &'static str = "acos"

Source

impl FuncName for Acosh

Source

const NAME: &'static str = "acosh"

Source

impl FuncName for AddDateInterval

Source

const NAME: &'static str = "add_date_interval"

Source

impl FuncName for AddDateTime

Source

const NAME: &'static str = "add_date_time"

Source

impl FuncName for AddFloat32

Source

const NAME: &'static str = "add_float32"

Source

impl FuncName for AddFloat64

Source

const NAME: &'static str = "add_float64"

Source

impl FuncName for AddInt16

Source

const NAME: &'static str = "add_int16"

Source

impl FuncName for AddInt32

Source

const NAME: &'static str = "add_int32"

Source

impl FuncName for AddInt64

Source

const NAME: &'static str = "add_int64"

Source

impl FuncName for AddInterval

Source

const NAME: &'static str = "add_interval"

Source

impl FuncName for AddNumeric

Source

const NAME: &'static str = "add_numeric"

Source

impl FuncName for AddTimeInterval

Source

const NAME: &'static str = "add_time_interval"

Source

impl FuncName for AddTimestampInterval

Source

const NAME: &'static str = "add_timestamp_interval"

Source

impl FuncName for AddTimestampTzInterval

Source

const NAME: &'static str = "add_timestamp_tz_interval"

Source

impl FuncName for AddUint16

Source

const NAME: &'static str = "add_uint16"

Source

impl FuncName for AddUint32

Source

const NAME: &'static str = "add_uint32"

Source

impl FuncName for AddUint64

Source

const NAME: &'static str = "add_uint64"

Source

impl FuncName for AdjustNumericScale

Source

const NAME: &'static str = "adjust_numeric_scale"

Source

impl FuncName for AdjustTimestampPrecision

Source

const NAME: &'static str = "adjust_timestamp_precision"

Source

impl FuncName for AdjustTimestampTzPrecision

Source

const NAME: &'static str = "adjust_timestamp_tz_precision"

Source

impl FuncName for AgeTimestamp

Source

const NAME: &'static str = "age_timestamp"

Source

impl FuncName for AgeTimestampTz

Source

const NAME: &'static str = "age_timestamp_tz"

Source

impl FuncName for And

Source

const NAME: &'static str = "and"

Source

impl FuncName for ArrayArrayConcat

Source

const NAME: &'static str = "array_array_concat"

Source

impl FuncName for ArrayContains

Source

const NAME: &'static str = "array_contains"

Source

impl FuncName for ArrayContainsArray

Source

const NAME: &'static str = "array_contains_array"

Source

impl FuncName for ArrayContainsArrayRev

Source

const NAME: &'static str = "array_contains_array_rev"

Source

impl FuncName for ArrayCreate

Source

const NAME: &'static str = "array_create"

Source

impl FuncName for ArrayFill

Source

const NAME: &'static str = "array_fill"

Source

impl FuncName for ArrayIndex

Source

const NAME: &'static str = "array_index"

Source

impl FuncName for ArrayLength

Source

const NAME: &'static str = "array_length"

Source

impl FuncName for ArrayLower

Source

const NAME: &'static str = "array_lower"

Source

impl FuncName for ArrayPosition

Source

const NAME: &'static str = "array_position"

Source

impl FuncName for ArrayRemove

Source

const NAME: &'static str = "array_remove"

Source

impl FuncName for ArrayToString

Source

const NAME: &'static str = "array_to_string"

Source

impl FuncName for ArrayUpper

Source

const NAME: &'static str = "array_upper"

Source

impl FuncName for Ascii

Source

const NAME: &'static str = "ascii"

Source

impl FuncName for Asin

Source

const NAME: &'static str = "asin"

Source

impl FuncName for Asinh

Source

const NAME: &'static str = "asinh"

Source

impl FuncName for Atan

Source

const NAME: &'static str = "atan"

Source

impl FuncName for Atanh

Source

const NAME: &'static str = "atanh"

Source

impl FuncName for BitAndInt16

Source

const NAME: &'static str = "bit_and_int16"

Source

impl FuncName for BitAndInt32

Source

const NAME: &'static str = "bit_and_int32"

Source

impl FuncName for BitAndInt64

Source

const NAME: &'static str = "bit_and_int64"

Source

impl FuncName for BitAndUint16

Source

const NAME: &'static str = "bit_and_uint16"

Source

impl FuncName for BitAndUint32

Source

const NAME: &'static str = "bit_and_uint32"

Source

impl FuncName for BitAndUint64

Source

const NAME: &'static str = "bit_and_uint64"

Source

impl FuncName for BitCountBytes

Source

const NAME: &'static str = "bit_count_bytes"

Source

impl FuncName for BitLengthBytes

Source

const NAME: &'static str = "bit_length_bytes"

Source

impl FuncName for BitLengthString

Source

const NAME: &'static str = "bit_length_string"

Source

impl FuncName for BitNotInt16

Source

const NAME: &'static str = "bit_not_int16"

Source

impl FuncName for BitNotInt32

Source

const NAME: &'static str = "bit_not_int32"

Source

impl FuncName for BitNotInt64

Source

const NAME: &'static str = "bit_not_int64"

Source

impl FuncName for BitNotUint16

Source

const NAME: &'static str = "bit_not_uint16"

Source

impl FuncName for BitNotUint32

Source

const NAME: &'static str = "bit_not_uint32"

Source

impl FuncName for BitNotUint64

Source

const NAME: &'static str = "bit_not_uint64"

Source

impl FuncName for BitOrInt16

Source

const NAME: &'static str = "bit_or_int16"

Source

impl FuncName for BitOrInt32

Source

const NAME: &'static str = "bit_or_int32"

Source

impl FuncName for BitOrInt64

Source

const NAME: &'static str = "bit_or_int64"

Source

impl FuncName for BitOrUint16

Source

const NAME: &'static str = "bit_or_uint16"

Source

impl FuncName for BitOrUint32

Source

const NAME: &'static str = "bit_or_uint32"

Source

impl FuncName for BitOrUint64

Source

const NAME: &'static str = "bit_or_uint64"

Source

impl FuncName for BitShiftLeftInt16

Source

const NAME: &'static str = "bit_shift_left_int16"

Source

impl FuncName for BitShiftLeftInt32

Source

const NAME: &'static str = "bit_shift_left_int32"

Source

impl FuncName for BitShiftLeftInt64

Source

const NAME: &'static str = "bit_shift_left_int64"

Source

impl FuncName for BitShiftLeftUint16

Source

const NAME: &'static str = "bit_shift_left_uint16"

Source

impl FuncName for BitShiftLeftUint32

Source

const NAME: &'static str = "bit_shift_left_uint32"

Source

impl FuncName for BitShiftLeftUint64

Source

const NAME: &'static str = "bit_shift_left_uint64"

Source

impl FuncName for BitShiftRightInt16

Source

const NAME: &'static str = "bit_shift_right_int16"

Source

impl FuncName for BitShiftRightInt32

Source

const NAME: &'static str = "bit_shift_right_int32"

Source

impl FuncName for BitShiftRightInt64

Source

const NAME: &'static str = "bit_shift_right_int64"

Source

impl FuncName for BitShiftRightUint16

Source

const NAME: &'static str = "bit_shift_right_uint16"

Source

impl FuncName for BitShiftRightUint32

Source

const NAME: &'static str = "bit_shift_right_uint32"

Source

impl FuncName for BitShiftRightUint64

Source

const NAME: &'static str = "bit_shift_right_uint64"

Source

impl FuncName for BitXorInt16

Source

const NAME: &'static str = "bit_xor_int16"

Source

impl FuncName for BitXorInt32

Source

const NAME: &'static str = "bit_xor_int32"

Source

impl FuncName for BitXorInt64

Source

const NAME: &'static str = "bit_xor_int64"

Source

impl FuncName for BitXorUint16

Source

const NAME: &'static str = "bit_xor_uint16"

Source

impl FuncName for BitXorUint32

Source

const NAME: &'static str = "bit_xor_uint32"

Source

impl FuncName for BitXorUint64

Source

const NAME: &'static str = "bit_xor_uint64"

Source

impl FuncName for ByteLengthBytes

Source

const NAME: &'static str = "byte_length_bytes"

Source

impl FuncName for ByteLengthString

Source

const NAME: &'static str = "byte_length_string"

Source

impl FuncName for CaseLiteral

Source

const NAME: &'static str = "case_literal"

Source

impl FuncName for CastArrayToArray

Source

const NAME: &'static str = "cast_array_to_array"

Source

impl FuncName for CastArrayToJsonb

Source

const NAME: &'static str = "cast_array_to_jsonb"

Source

impl FuncName for CastArrayToListOneDim

Source

const NAME: &'static str = "cast_array_to_list_one_dim"

Source

impl FuncName for CastArrayToString

Source

const NAME: &'static str = "cast_array_to_string"

Source

impl FuncName for CastBoolToInt32

Source

const NAME: &'static str = "cast_bool_to_int32"

Source

impl FuncName for CastBoolToInt64

Source

const NAME: &'static str = "cast_bool_to_int64"

Source

impl FuncName for CastBoolToString

Source

const NAME: &'static str = "cast_bool_to_string"

Source

impl FuncName for CastBoolToStringNonstandard

Source

const NAME: &'static str = "cast_bool_to_string_nonstandard"

Source

impl FuncName for CastBytesToString

Source

const NAME: &'static str = "cast_bytes_to_string"

Source

impl FuncName for CastCharToString

Source

const NAME: &'static str = "cast_char_to_string"

Source

impl FuncName for CastDateToMzTimestamp

Source

const NAME: &'static str = "cast_date_to_mz_timestamp"

Source

impl FuncName for CastDateToString

Source

const NAME: &'static str = "cast_date_to_string"

Source

impl FuncName for CastDateToTimestamp

Source

const NAME: &'static str = "cast_date_to_timestamp"

Source

impl FuncName for CastDateToTimestampTz

Source

const NAME: &'static str = "cast_date_to_timestamp_tz"

Source

impl FuncName for CastFloat32ToFloat64

Source

const NAME: &'static str = "cast_float32_to_float64"

Source

impl FuncName for CastFloat32ToInt16

Source

const NAME: &'static str = "cast_float32_to_int16"

Source

impl FuncName for CastFloat32ToInt32

Source

const NAME: &'static str = "cast_float32_to_int32"

Source

impl FuncName for CastFloat32ToInt64

Source

const NAME: &'static str = "cast_float32_to_int64"

Source

impl FuncName for CastFloat32ToNumeric

Source

const NAME: &'static str = "cast_float32_to_numeric"

Source

impl FuncName for CastFloat32ToString

Source

const NAME: &'static str = "cast_float32_to_string"

Source

impl FuncName for CastFloat32ToUint16

Source

const NAME: &'static str = "cast_float32_to_uint16"

Source

impl FuncName for CastFloat32ToUint32

Source

const NAME: &'static str = "cast_float32_to_uint32"

Source

impl FuncName for CastFloat32ToUint64

Source

const NAME: &'static str = "cast_float32_to_uint64"

Source

impl FuncName for CastFloat64ToFloat32

Source

const NAME: &'static str = "cast_float64_to_float32"

Source

impl FuncName for CastFloat64ToInt16

Source

const NAME: &'static str = "cast_float64_to_int16"

Source

impl FuncName for CastFloat64ToInt32

Source

const NAME: &'static str = "cast_float64_to_int32"

Source

impl FuncName for CastFloat64ToInt64

Source

const NAME: &'static str = "cast_float64_to_int64"

Source

impl FuncName for CastFloat64ToNumeric

Source

const NAME: &'static str = "cast_float64_to_numeric"

Source

impl FuncName for CastFloat64ToString

Source

const NAME: &'static str = "cast_float64_to_string"

Source

impl FuncName for CastFloat64ToUint16

Source

const NAME: &'static str = "cast_float64_to_uint16"

Source

impl FuncName for CastFloat64ToUint32

Source

const NAME: &'static str = "cast_float64_to_uint32"

Source

impl FuncName for CastFloat64ToUint64

Source

const NAME: &'static str = "cast_float64_to_uint64"

Source

impl FuncName for CastInt2VectorToArray

Source

const NAME: &'static str = "cast_int2_vector_to_array"

Source

impl FuncName for CastInt2VectorToString

Source

const NAME: &'static str = "cast_int2_vector_to_string"

Source

impl FuncName for CastInt16ToFloat32

Source

const NAME: &'static str = "cast_int16_to_float32"

Source

impl FuncName for CastInt16ToFloat64

Source

const NAME: &'static str = "cast_int16_to_float64"

Source

impl FuncName for CastInt16ToInt32

Source

const NAME: &'static str = "cast_int16_to_int32"

Source

impl FuncName for CastInt16ToInt64

Source

const NAME: &'static str = "cast_int16_to_int64"

Source

impl FuncName for CastInt16ToNumeric

Source

const NAME: &'static str = "cast_int16_to_numeric"

Source

impl FuncName for CastInt16ToString

Source

const NAME: &'static str = "cast_int16_to_string"

Source

impl FuncName for CastInt16ToUint16

Source

const NAME: &'static str = "cast_int16_to_uint16"

Source

impl FuncName for CastInt16ToUint32

Source

const NAME: &'static str = "cast_int16_to_uint32"

Source

impl FuncName for CastInt16ToUint64

Source

const NAME: &'static str = "cast_int16_to_uint64"

Source

impl FuncName for CastInt32ToBool

Source

const NAME: &'static str = "cast_int32_to_bool"

Source

impl FuncName for CastInt32ToFloat32

Source

const NAME: &'static str = "cast_int32_to_float32"

Source

impl FuncName for CastInt32ToFloat64

Source

const NAME: &'static str = "cast_int32_to_float64"

Source

impl FuncName for CastInt32ToInt16

Source

const NAME: &'static str = "cast_int32_to_int16"

Source

impl FuncName for CastInt32ToInt64

Source

const NAME: &'static str = "cast_int32_to_int64"

Source

impl FuncName for CastInt32ToMzTimestamp

Source

const NAME: &'static str = "cast_int32_to_mz_timestamp"

Source

impl FuncName for CastInt32ToNumeric

Source

const NAME: &'static str = "cast_int32_to_numeric"

Source

impl FuncName for CastInt32ToOid

Source

const NAME: &'static str = "cast_int32_to_oid"

Source

impl FuncName for CastInt32ToPgLegacyChar

Source

const NAME: &'static str = "cast_int32_to_pg_legacy_char"

Source

impl FuncName for CastInt32ToString

Source

const NAME: &'static str = "cast_int32_to_string"

Source

impl FuncName for CastInt32ToUint16

Source

const NAME: &'static str = "cast_int32_to_uint16"

Source

impl FuncName for CastInt32ToUint32

Source

const NAME: &'static str = "cast_int32_to_uint32"

Source

impl FuncName for CastInt32ToUint64

Source

const NAME: &'static str = "cast_int32_to_uint64"

Source

impl FuncName for CastInt64ToBool

Source

const NAME: &'static str = "cast_int64_to_bool"

Source

impl FuncName for CastInt64ToFloat32

Source

const NAME: &'static str = "cast_int64_to_float32"

Source

impl FuncName for CastInt64ToFloat64

Source

const NAME: &'static str = "cast_int64_to_float64"

Source

impl FuncName for CastInt64ToInt16

Source

const NAME: &'static str = "cast_int64_to_int16"

Source

impl FuncName for CastInt64ToInt32

Source

const NAME: &'static str = "cast_int64_to_int32"

Source

impl FuncName for CastInt64ToMzTimestamp

Source

const NAME: &'static str = "cast_int64_to_mz_timestamp"

Source

impl FuncName for CastInt64ToNumeric

Source

const NAME: &'static str = "cast_int64_to_numeric"

Source

impl FuncName for CastInt64ToOid

Source

const NAME: &'static str = "cast_int64_to_oid"

Source

impl FuncName for CastInt64ToString

Source

const NAME: &'static str = "cast_int64_to_string"

Source

impl FuncName for CastInt64ToUint16

Source

const NAME: &'static str = "cast_int64_to_uint16"

Source

impl FuncName for CastInt64ToUint32

Source

const NAME: &'static str = "cast_int64_to_uint32"

Source

impl FuncName for CastInt64ToUint64

Source

const NAME: &'static str = "cast_int64_to_uint64"

Source

impl FuncName for CastIntervalToString

Source

const NAME: &'static str = "cast_interval_to_string"

Source

impl FuncName for CastIntervalToTime

Source

const NAME: &'static str = "cast_interval_to_time"

Source

impl FuncName for CastJsonbToBool

Source

const NAME: &'static str = "cast_jsonb_to_bool"

Source

impl FuncName for CastJsonbToFloat32

Source

const NAME: &'static str = "cast_jsonb_to_float32"

Source

impl FuncName for CastJsonbToFloat64

Source

const NAME: &'static str = "cast_jsonb_to_float64"

Source

impl FuncName for CastJsonbToInt16

Source

const NAME: &'static str = "cast_jsonb_to_int16"

Source

impl FuncName for CastJsonbToInt32

Source

const NAME: &'static str = "cast_jsonb_to_int32"

Source

impl FuncName for CastJsonbToInt64

Source

const NAME: &'static str = "cast_jsonb_to_int64"

Source

impl FuncName for CastJsonbToNumeric

Source

const NAME: &'static str = "cast_jsonb_to_numeric"

Source

impl FuncName for CastJsonbToString

Source

const NAME: &'static str = "cast_jsonb_to_string"

Source

impl FuncName for CastJsonbableToJsonb

Source

const NAME: &'static str = "cast_jsonbable_to_jsonb"

Source

impl FuncName for CastList1ToList2

Source

const NAME: &'static str = "cast_list1_to_list2"

Source

impl FuncName for CastListToJsonb

Source

const NAME: &'static str = "cast_list_to_jsonb"

Source

impl FuncName for CastListToString

Source

const NAME: &'static str = "cast_list_to_string"

Source

impl FuncName for CastMapToString

Source

const NAME: &'static str = "cast_map_to_string"

Source

impl FuncName for CastMzTimestampToString

Source

const NAME: &'static str = "cast_mz_timestamp_to_string"

Source

impl FuncName for CastMzTimestampToTimestamp

Source

const NAME: &'static str = "cast_mz_timestamp_to_timestamp"

Source

impl FuncName for CastMzTimestampToTimestampTz

Source

const NAME: &'static str = "cast_mz_timestamp_to_timestamp_tz"

Source

impl FuncName for CastNumericToFloat32

Source

const NAME: &'static str = "cast_numeric_to_float32"

Source

impl FuncName for CastNumericToFloat64

Source

const NAME: &'static str = "cast_numeric_to_float64"

Source

impl FuncName for CastNumericToInt16

Source

const NAME: &'static str = "cast_numeric_to_int16"

Source

impl FuncName for CastNumericToInt32

Source

const NAME: &'static str = "cast_numeric_to_int32"

Source

impl FuncName for CastNumericToInt64

Source

const NAME: &'static str = "cast_numeric_to_int64"

Source

impl FuncName for CastNumericToMzTimestamp

Source

const NAME: &'static str = "cast_numeric_to_mz_timestamp"

Source

impl FuncName for CastNumericToString

Source

const NAME: &'static str = "cast_numeric_to_string"

Source

impl FuncName for CastNumericToUint16

Source

const NAME: &'static str = "cast_numeric_to_uint16"

Source

impl FuncName for CastNumericToUint32

Source

const NAME: &'static str = "cast_numeric_to_uint32"

Source

impl FuncName for CastNumericToUint64

Source

const NAME: &'static str = "cast_numeric_to_uint64"

Source

impl FuncName for CastOidToInt32

Source

const NAME: &'static str = "cast_oid_to_int32"

Source

impl FuncName for CastOidToInt64

Source

const NAME: &'static str = "cast_oid_to_int64"

Source

impl FuncName for CastOidToRegClass

Source

const NAME: &'static str = "cast_oid_to_reg_class"

Source

impl FuncName for CastOidToRegProc

Source

const NAME: &'static str = "cast_oid_to_reg_proc"

Source

impl FuncName for CastOidToRegType

Source

const NAME: &'static str = "cast_oid_to_reg_type"

Source

impl FuncName for CastOidToString

Source

const NAME: &'static str = "cast_oid_to_string"

Source

impl FuncName for CastPgLegacyCharToChar

Source

const NAME: &'static str = "cast_pg_legacy_char_to_char"

Source

impl FuncName for CastPgLegacyCharToInt32

Source

const NAME: &'static str = "cast_pg_legacy_char_to_int32"

Source

impl FuncName for CastPgLegacyCharToString

Source

const NAME: &'static str = "cast_pg_legacy_char_to_string"

Source

impl FuncName for CastPgLegacyCharToVarChar

Source

const NAME: &'static str = "cast_pg_legacy_char_to_var_char"

Source

impl FuncName for CastRangeToString

Source

const NAME: &'static str = "cast_range_to_string"

Source

impl FuncName for CastRecord1ToRecord2

Source

const NAME: &'static str = "cast_record1_to_record2"

Source

impl FuncName for CastRecordToString

Source

const NAME: &'static str = "cast_record_to_string"

Source

impl FuncName for CastRegClassToOid

Source

const NAME: &'static str = "cast_reg_class_to_oid"

Source

impl FuncName for CastRegProcToOid

Source

const NAME: &'static str = "cast_reg_proc_to_oid"

Source

impl FuncName for CastRegTypeToOid

Source

const NAME: &'static str = "cast_reg_type_to_oid"

Source

impl FuncName for CastStringToArray

Source

const NAME: &'static str = "cast_string_to_array"

Source

impl FuncName for CastStringToBool

Source

const NAME: &'static str = "cast_string_to_bool"

Source

impl FuncName for CastStringToBytes

Source

const NAME: &'static str = "cast_string_to_bytes"

Source

impl FuncName for CastStringToChar

Source

const NAME: &'static str = "cast_string_to_char"

Source

impl FuncName for CastStringToDate

Source

const NAME: &'static str = "cast_string_to_date"

Source

impl FuncName for CastStringToFloat32

Source

const NAME: &'static str = "cast_string_to_float32"

Source

impl FuncName for CastStringToFloat64

Source

const NAME: &'static str = "cast_string_to_float64"

Source

impl FuncName for CastStringToInt2Vector

Source

const NAME: &'static str = "cast_string_to_int2_vector"

Source

impl FuncName for CastStringToInt16

Source

const NAME: &'static str = "cast_string_to_int16"

Source

impl FuncName for CastStringToInt32

Source

const NAME: &'static str = "cast_string_to_int32"

Source

impl FuncName for CastStringToInt64

Source

const NAME: &'static str = "cast_string_to_int64"

Source

impl FuncName for CastStringToInterval

Source

const NAME: &'static str = "cast_string_to_interval"

Source

impl FuncName for CastStringToJsonb

Source

const NAME: &'static str = "cast_string_to_jsonb"

Source

impl FuncName for CastStringToList

Source

const NAME: &'static str = "cast_string_to_list"

Source

impl FuncName for CastStringToMap

Source

const NAME: &'static str = "cast_string_to_map"

Source

impl FuncName for CastStringToMzTimestamp

Source

const NAME: &'static str = "cast_string_to_mz_timestamp"

Source

impl FuncName for CastStringToNumeric

Source

const NAME: &'static str = "cast_string_to_numeric"

Source

impl FuncName for CastStringToOid

Source

const NAME: &'static str = "cast_string_to_oid"

Source

impl FuncName for CastStringToPgLegacyChar

Source

const NAME: &'static str = "cast_string_to_pg_legacy_char"

Source

impl FuncName for CastStringToPgLegacyName

Source

const NAME: &'static str = "cast_string_to_pg_legacy_name"

Source

impl FuncName for CastStringToRange

Source

const NAME: &'static str = "cast_string_to_range"

Source

impl FuncName for CastStringToTime

Source

const NAME: &'static str = "cast_string_to_time"

Source

impl FuncName for CastStringToTimestamp

Source

const NAME: &'static str = "cast_string_to_timestamp"

Source

impl FuncName for CastStringToTimestampTz

Source

const NAME: &'static str = "cast_string_to_timestamp_tz"

Source

impl FuncName for CastStringToUint16

Source

const NAME: &'static str = "cast_string_to_uint16"

Source

impl FuncName for CastStringToUint32

Source

const NAME: &'static str = "cast_string_to_uint32"

Source

impl FuncName for CastStringToUint64

Source

const NAME: &'static str = "cast_string_to_uint64"

Source

impl FuncName for CastStringToUuid

Source

const NAME: &'static str = "cast_string_to_uuid"

Source

impl FuncName for CastStringToVarChar

Source

const NAME: &'static str = "cast_string_to_var_char"

Source

impl FuncName for CastTimeToInterval

Source

const NAME: &'static str = "cast_time_to_interval"

Source

impl FuncName for CastTimeToString

Source

const NAME: &'static str = "cast_time_to_string"

Source

impl FuncName for CastTimestampToDate

Source

const NAME: &'static str = "cast_timestamp_to_date"

Source

impl FuncName for CastTimestampToMzTimestamp

Source

const NAME: &'static str = "cast_timestamp_to_mz_timestamp"

Source

impl FuncName for CastTimestampToString

Source

const NAME: &'static str = "cast_timestamp_to_string"

Source

impl FuncName for CastTimestampToTime

Source

const NAME: &'static str = "cast_timestamp_to_time"

Source

impl FuncName for CastTimestampToTimestampTz

Source

const NAME: &'static str = "cast_timestamp_to_timestamp_tz"

Source

impl FuncName for CastTimestampTzToDate

Source

const NAME: &'static str = "cast_timestamp_tz_to_date"

Source

impl FuncName for CastTimestampTzToMzTimestamp

Source

const NAME: &'static str = "cast_timestamp_tz_to_mz_timestamp"

Source

impl FuncName for CastTimestampTzToString

Source

const NAME: &'static str = "cast_timestamp_tz_to_string"

Source

impl FuncName for CastTimestampTzToTime

Source

const NAME: &'static str = "cast_timestamp_tz_to_time"

Source

impl FuncName for CastTimestampTzToTimestamp

Source

const NAME: &'static str = "cast_timestamp_tz_to_timestamp"

Source

impl FuncName for CastUint16ToFloat32

Source

const NAME: &'static str = "cast_uint16_to_float32"

Source

impl FuncName for CastUint16ToFloat64

Source

const NAME: &'static str = "cast_uint16_to_float64"

Source

impl FuncName for CastUint16ToInt16

Source

const NAME: &'static str = "cast_uint16_to_int16"

Source

impl FuncName for CastUint16ToInt32

Source

const NAME: &'static str = "cast_uint16_to_int32"

Source

impl FuncName for CastUint16ToInt64

Source

const NAME: &'static str = "cast_uint16_to_int64"

Source

impl FuncName for CastUint16ToNumeric

Source

const NAME: &'static str = "cast_uint16_to_numeric"

Source

impl FuncName for CastUint16ToString

Source

const NAME: &'static str = "cast_uint16_to_string"

Source

impl FuncName for CastUint16ToUint32

Source

const NAME: &'static str = "cast_uint16_to_uint32"

Source

impl FuncName for CastUint16ToUint64

Source

const NAME: &'static str = "cast_uint16_to_uint64"

Source

impl FuncName for CastUint32ToFloat32

Source

const NAME: &'static str = "cast_uint32_to_float32"

Source

impl FuncName for CastUint32ToFloat64

Source

const NAME: &'static str = "cast_uint32_to_float64"

Source

impl FuncName for CastUint32ToInt16

Source

const NAME: &'static str = "cast_uint32_to_int16"

Source

impl FuncName for CastUint32ToInt32

Source

const NAME: &'static str = "cast_uint32_to_int32"

Source

impl FuncName for CastUint32ToInt64

Source

const NAME: &'static str = "cast_uint32_to_int64"

Source

impl FuncName for CastUint32ToMzTimestamp

Source

const NAME: &'static str = "cast_uint32_to_mz_timestamp"

Source

impl FuncName for CastUint32ToNumeric

Source

const NAME: &'static str = "cast_uint32_to_numeric"

Source

impl FuncName for CastUint32ToString

Source

const NAME: &'static str = "cast_uint32_to_string"

Source

impl FuncName for CastUint32ToUint16

Source

const NAME: &'static str = "cast_uint32_to_uint16"

Source

impl FuncName for CastUint32ToUint64

Source

const NAME: &'static str = "cast_uint32_to_uint64"

Source

impl FuncName for CastUint64ToFloat32

Source

const NAME: &'static str = "cast_uint64_to_float32"

Source

impl FuncName for CastUint64ToFloat64

Source

const NAME: &'static str = "cast_uint64_to_float64"

Source

impl FuncName for CastUint64ToInt16

Source

const NAME: &'static str = "cast_uint64_to_int16"

Source

impl FuncName for CastUint64ToInt32

Source

const NAME: &'static str = "cast_uint64_to_int32"

Source

impl FuncName for CastUint64ToInt64

Source

const NAME: &'static str = "cast_uint64_to_int64"

Source

impl FuncName for CastUint64ToMzTimestamp

Source

const NAME: &'static str = "cast_uint64_to_mz_timestamp"

Source

impl FuncName for CastUint64ToNumeric

Source

const NAME: &'static str = "cast_uint64_to_numeric"

Source

impl FuncName for CastUint64ToString

Source

const NAME: &'static str = "cast_uint64_to_string"

Source

impl FuncName for CastUint64ToUint16

Source

const NAME: &'static str = "cast_uint64_to_uint16"

Source

impl FuncName for CastUint64ToUint32

Source

const NAME: &'static str = "cast_uint64_to_uint32"

Source

impl FuncName for CastUuidToString

Source

const NAME: &'static str = "cast_uuid_to_string"

Source

impl FuncName for CastVarCharToString

Source

const NAME: &'static str = "cast_var_char_to_string"

Source

impl FuncName for CbrtFloat64

Source

const NAME: &'static str = "cbrt_float64"

Source

impl FuncName for CeilFloat32

Source

const NAME: &'static str = "ceil_float32"

Source

impl FuncName for CeilFloat64

Source

const NAME: &'static str = "ceil_float64"

Source

impl FuncName for CeilNumeric

Source

const NAME: &'static str = "ceil_numeric"

Source

impl FuncName for CharLength

Source

const NAME: &'static str = "char_length"

Source

impl FuncName for Chr

Source

const NAME: &'static str = "chr"

Source

impl FuncName for Coalesce

Source

const NAME: &'static str = "coalesce"

Source

impl FuncName for Concat

Source

const NAME: &'static str = "concat"

Source

impl FuncName for ConcatWs

Source

const NAME: &'static str = "concat_ws"

Source

impl FuncName for ConstantTimeEqBytes

Source

const NAME: &'static str = "constant_time_eq_bytes"

Source

impl FuncName for ConstantTimeEqString

Source

const NAME: &'static str = "constant_time_eq_string"

Source

impl FuncName for ConvertFrom

Source

const NAME: &'static str = "convert_from"

Source

impl FuncName for Cos

Source

const NAME: &'static str = "cos"

Source

impl FuncName for Cosh

Source

const NAME: &'static str = "cosh"

Source

impl FuncName for Cot

Source

const NAME: &'static str = "cot"

Source

impl FuncName for Crc32Bytes

Source

const NAME: &'static str = "crc32_bytes"

Source

impl FuncName for Crc32String

Source

const NAME: &'static str = "crc32_string"

Source

impl FuncName for mz_expr::func::variadic::DateBinTimestamp

Source

const NAME: &'static str = "date_bin_timestamp"

Source

impl FuncName for mz_expr::func::DateBinTimestamp

Source

const NAME: &'static str = "date_bin_timestamp"

Source

impl FuncName for mz_expr::func::variadic::DateBinTimestampTz

Source

const NAME: &'static str = "date_bin_timestamp_tz"

Source

impl FuncName for mz_expr::func::DateBinTimestampTz

Source

const NAME: &'static str = "date_bin_timestamp_tz"

Source

impl FuncName for DateDiffDate

Source

const NAME: &'static str = "date_diff_date"

Source

impl FuncName for DateDiffTime

Source

const NAME: &'static str = "date_diff_time"

Source

impl FuncName for DateDiffTimestamp

Source

const NAME: &'static str = "date_diff_timestamp"

Source

impl FuncName for DateDiffTimestampTz

Source

const NAME: &'static str = "date_diff_timestamp_tz"

Source

impl FuncName for DatePartInterval

Source

const NAME: &'static str = "date_part_interval"

Source

impl FuncName for DatePartIntervalF64

Source

const NAME: &'static str = "date_part_interval_f64"

Source

impl FuncName for DatePartIntervalNumeric

Source

const NAME: &'static str = "date_part_interval_numeric"

Source

impl FuncName for DatePartTime

Source

const NAME: &'static str = "date_part_time"

Source

impl FuncName for DatePartTimeF64

Source

const NAME: &'static str = "date_part_time_f64"

Source

impl FuncName for DatePartTimeNumeric

Source

const NAME: &'static str = "date_part_time_numeric"

Source

impl FuncName for DatePartTimestamp

Source

const NAME: &'static str = "date_part_timestamp"

Source

impl FuncName for DatePartTimestampTimestampF64

Source

const NAME: &'static str = "date_part_timestamp_timestamp_f64"

Source

impl FuncName for DatePartTimestampTimestampNumeric

Source

const NAME: &'static str = "date_part_timestamp_timestamp_numeric"

Source

impl FuncName for DatePartTimestampTimestampTzF64

Source

const NAME: &'static str = "date_part_timestamp_timestamp_tz_f64"

Source

impl FuncName for DatePartTimestampTimestampTzNumeric

Source

const NAME: &'static str = "date_part_timestamp_timestamp_tz_numeric"

Source

impl FuncName for DatePartTimestampTz

Source

const NAME: &'static str = "date_part_timestamp_tz"

Source

impl FuncName for DateTruncInterval

Source

const NAME: &'static str = "date_trunc_interval"

Source

impl FuncName for DateTruncTimestamp

Source

const NAME: &'static str = "date_trunc_timestamp"

Source

impl FuncName for DateTruncTimestampTz

Source

const NAME: &'static str = "date_trunc_timestamp_tz"

Source

impl FuncName for DateTruncUnitsTimestamp

Source

const NAME: &'static str = "date_trunc_units_timestamp"

Source

impl FuncName for DateTruncUnitsTimestampTz

Source

const NAME: &'static str = "date_trunc_units_timestamp_tz"

Source

impl FuncName for Decode

Source

const NAME: &'static str = "decode"

Source

impl FuncName for Degrees

Source

const NAME: &'static str = "degrees"

Source

impl FuncName for DigestBytes

Source

const NAME: &'static str = "digest_bytes"

Source

impl FuncName for DigestString

Source

const NAME: &'static str = "digest_string"

Source

impl FuncName for DivFloat32

Source

const NAME: &'static str = "div_float32"

Source

impl FuncName for DivFloat64

Source

const NAME: &'static str = "div_float64"

Source

impl FuncName for DivInt16

Source

const NAME: &'static str = "div_int16"

Source

impl FuncName for DivInt32

Source

const NAME: &'static str = "div_int32"

Source

impl FuncName for DivInt64

Source

const NAME: &'static str = "div_int64"

Source

impl FuncName for DivInterval

Source

const NAME: &'static str = "div_interval"

Source

impl FuncName for DivNumeric

Source

const NAME: &'static str = "div_numeric"

Source

impl FuncName for DivUint16

Source

const NAME: &'static str = "div_uint16"

Source

impl FuncName for DivUint32

Source

const NAME: &'static str = "div_uint32"

Source

impl FuncName for DivUint64

Source

const NAME: &'static str = "div_uint64"

Source

impl FuncName for ElementListConcat

Source

const NAME: &'static str = "element_list_concat"

Source

impl FuncName for Encode

Source

const NAME: &'static str = "encode"

Source

impl FuncName for EncodedBytesCharLength

Source

const NAME: &'static str = "encoded_bytes_char_length"

Source

impl FuncName for Eq

Source

const NAME: &'static str = "eq"

Source

impl FuncName for ErrorIfNull

Source

const NAME: &'static str = "error_if_null"

Source

impl FuncName for Exp

Source

const NAME: &'static str = "exp"

Source

impl FuncName for ExpNumeric

Source

const NAME: &'static str = "exp_numeric"

Source

impl FuncName for ExtractDate

Source

const NAME: &'static str = "extract_date"

Source

impl FuncName for ExtractDateUnits

Source

const NAME: &'static str = "extract_date_units"

Source

impl FuncName for ExtractInterval

Source

const NAME: &'static str = "extract_interval"

Source

impl FuncName for ExtractTime

Source

const NAME: &'static str = "extract_time"

Source

impl FuncName for ExtractTimestamp

Source

const NAME: &'static str = "extract_timestamp"

Source

impl FuncName for ExtractTimestampTz

Source

const NAME: &'static str = "extract_timestamp_tz"

Source

impl FuncName for FloorFloat32

Source

const NAME: &'static str = "floor_float32"

Source

impl FuncName for FloorFloat64

Source

const NAME: &'static str = "floor_float64"

Source

impl FuncName for FloorNumeric

Source

const NAME: &'static str = "floor_numeric"

Source

impl FuncName for GetBit

Source

const NAME: &'static str = "get_bit"

Source

impl FuncName for GetByte

Source

const NAME: &'static str = "get_byte"

Source

impl FuncName for Greatest

Source

const NAME: &'static str = "greatest"

Source

impl FuncName for Gt

Source

const NAME: &'static str = "gt"

Source

impl FuncName for Gte

Source

const NAME: &'static str = "gte"

Source

impl FuncName for HmacBytes

Source

const NAME: &'static str = "hmac_bytes"

Source

impl FuncName for HmacString

Source

const NAME: &'static str = "hmac_string"

Source

impl FuncName for Initcap

Source

const NAME: &'static str = "initcap"

Source

impl FuncName for IsFalse

Source

const NAME: &'static str = "is_false"

Source

impl FuncName for IsLikeMatch

Source

const NAME: &'static str = "is_like_match"

Source

impl FuncName for IsLikeMatchCaseInsensitive

Source

const NAME: &'static str = "is_like_match_case_insensitive"

Source

impl FuncName for IsLikeMatchCaseSensitive

Source

const NAME: &'static str = "is_like_match_case_sensitive"

Source

impl FuncName for IsNull

Source

const NAME: &'static str = "is_null"

Source

impl FuncName for IsRegexpMatch

Source

const NAME: &'static str = "is_regexp_match"

Source

impl FuncName for IsRegexpMatchCaseInsensitive

Source

const NAME: &'static str = "is_regexp_match_case_insensitive"

Source

impl FuncName for IsRegexpMatchCaseSensitive

Source

const NAME: &'static str = "is_regexp_match_case_sensitive"

Source

impl FuncName for IsTrue

Source

const NAME: &'static str = "is_true"

Source

impl FuncName for JsonbArrayLength

Source

const NAME: &'static str = "jsonb_array_length"

Source

impl FuncName for JsonbBuildArray

Source

const NAME: &'static str = "jsonb_build_array"

Source

impl FuncName for JsonbBuildObject

Source

const NAME: &'static str = "jsonb_build_object"

Source

impl FuncName for JsonbConcat

Source

const NAME: &'static str = "jsonb_concat"

Source

impl FuncName for JsonbContainsJsonb

Source

const NAME: &'static str = "jsonb_contains_jsonb"

Source

impl FuncName for JsonbContainsString

Source

const NAME: &'static str = "jsonb_contains_string"

Source

impl FuncName for JsonbDeleteInt64

Source

const NAME: &'static str = "jsonb_delete_int64"

Source

impl FuncName for JsonbDeleteString

Source

const NAME: &'static str = "jsonb_delete_string"

Source

impl FuncName for JsonbGetInt64

Source

const NAME: &'static str = "jsonb_get_int64"

Source

impl FuncName for JsonbGetInt64Stringify

Source

const NAME: &'static str = "jsonb_get_int64_stringify"

Source

impl FuncName for JsonbGetPath

Source

const NAME: &'static str = "jsonb_get_path"

Source

impl FuncName for JsonbGetPathStringify

Source

const NAME: &'static str = "jsonb_get_path_stringify"

Source

impl FuncName for JsonbGetString

Source

const NAME: &'static str = "jsonb_get_string"

Source

impl FuncName for JsonbGetStringStringify

Source

const NAME: &'static str = "jsonb_get_string_stringify"

Source

impl FuncName for JsonbPretty

Source

const NAME: &'static str = "jsonb_pretty"

Source

impl FuncName for JsonbStripNulls

Source

const NAME: &'static str = "jsonb_strip_nulls"

Source

impl FuncName for JsonbTypeof

Source

const NAME: &'static str = "jsonb_typeof"

Source

impl FuncName for JustifyDays

Source

const NAME: &'static str = "justify_days"

Source

impl FuncName for JustifyHours

Source

const NAME: &'static str = "justify_hours"

Source

impl FuncName for JustifyInterval

Source

const NAME: &'static str = "justify_interval"

Source

impl FuncName for KafkaMurmur2Bytes

Source

const NAME: &'static str = "kafka_murmur2_bytes"

Source

impl FuncName for KafkaMurmur2String

Source

const NAME: &'static str = "kafka_murmur2_string"

Source

impl FuncName for Least

Source

const NAME: &'static str = "least"

Source

impl FuncName for Left

Source

const NAME: &'static str = "left"

Source

impl FuncName for LikeEscape

Source

const NAME: &'static str = "like_escape"

Source

impl FuncName for ListContainsList

Source

const NAME: &'static str = "list_contains_list"

Source

impl FuncName for ListContainsListRev

Source

const NAME: &'static str = "list_contains_list_rev"

Source

impl FuncName for ListCreate

Source

const NAME: &'static str = "list_create"

Source

impl FuncName for ListElementConcat

Source

const NAME: &'static str = "list_element_concat"

Source

impl FuncName for ListIndex

Source

const NAME: &'static str = "list_index"

Source

impl FuncName for ListLength

Source

const NAME: &'static str = "list_length"

Source

impl FuncName for ListLengthMax

Source

const NAME: &'static str = "list_length_max"

Source

impl FuncName for ListListConcat

Source

const NAME: &'static str = "list_list_concat"

Source

impl FuncName for ListRemove

Source

const NAME: &'static str = "list_remove"

Source

impl FuncName for ListSliceLinear

Source

const NAME: &'static str = "list_slice_linear"

Source

impl FuncName for Ln

Source

const NAME: &'static str = "ln"

Source

impl FuncName for LnNumeric

Source

const NAME: &'static str = "ln_numeric"

Source

impl FuncName for Log10

Source

const NAME: &'static str = "log10"

Source

impl FuncName for Log10Numeric

Source

const NAME: &'static str = "log10_numeric"

Source

impl FuncName for LogBaseNumeric

Source

const NAME: &'static str = "log_base_numeric"

Source

impl FuncName for Lower

Source

const NAME: &'static str = "lower"

Source

impl FuncName for Lt

Source

const NAME: &'static str = "lt"

Source

impl FuncName for Lte

Source

const NAME: &'static str = "lte"

Source

impl FuncName for MakeAclItem

Source

const NAME: &'static str = "make_acl_item"

Source

impl FuncName for MakeMzAclItem

Source

const NAME: &'static str = "make_mz_acl_item"

Source

impl FuncName for MakeTimestamp

Source

const NAME: &'static str = "make_timestamp"

Source

impl FuncName for MapBuild

Source

const NAME: &'static str = "map_build"

Source

impl FuncName for MapBuildFromRecordList

Source

const NAME: &'static str = "map_build_from_record_list"

Source

impl FuncName for MapContainsAllKeys

Source

const NAME: &'static str = "map_contains_all_keys"

Source

impl FuncName for MapContainsAnyKeys

Source

const NAME: &'static str = "map_contains_any_keys"

Source

impl FuncName for MapContainsKey

Source

const NAME: &'static str = "map_contains_key"

Source

impl FuncName for MapContainsMap

Source

const NAME: &'static str = "map_contains_map"

Source

impl FuncName for MapGetValue

Source

const NAME: &'static str = "map_get_value"

Source

impl FuncName for MapLength

Source

const NAME: &'static str = "map_length"

Source

impl FuncName for ModFloat32

Source

const NAME: &'static str = "mod_float32"

Source

impl FuncName for ModFloat64

Source

const NAME: &'static str = "mod_float64"

Source

impl FuncName for ModInt16

Source

const NAME: &'static str = "mod_int16"

Source

impl FuncName for ModInt32

Source

const NAME: &'static str = "mod_int32"

Source

impl FuncName for ModInt64

Source

const NAME: &'static str = "mod_int64"

Source

impl FuncName for ModNumeric

Source

const NAME: &'static str = "mod_numeric"

Source

impl FuncName for ModUint16

Source

const NAME: &'static str = "mod_uint16"

Source

impl FuncName for ModUint32

Source

const NAME: &'static str = "mod_uint32"

Source

impl FuncName for ModUint64

Source

const NAME: &'static str = "mod_uint64"

Source

impl FuncName for MulFloat32

Source

const NAME: &'static str = "mul_float32"

Source

impl FuncName for MulFloat64

Source

const NAME: &'static str = "mul_float64"

Source

impl FuncName for MulInt16

Source

const NAME: &'static str = "mul_int16"

Source

impl FuncName for MulInt32

Source

const NAME: &'static str = "mul_int32"

Source

impl FuncName for MulInt64

Source

const NAME: &'static str = "mul_int64"

Source

impl FuncName for MulInterval

Source

const NAME: &'static str = "mul_interval"

Source

impl FuncName for MulNumeric

Source

const NAME: &'static str = "mul_numeric"

Source

impl FuncName for MulUint16

Source

const NAME: &'static str = "mul_uint16"

Source

impl FuncName for MulUint32

Source

const NAME: &'static str = "mul_uint32"

Source

impl FuncName for MulUint64

Source

const NAME: &'static str = "mul_uint64"

Source

impl FuncName for MzAclItemContainsPrivilege

Source

const NAME: &'static str = "mz_acl_item_contains_privilege"

Source

impl FuncName for MzAclItemGrantee

Source

const NAME: &'static str = "mz_acl_item_grantee"

Source

impl FuncName for MzAclItemGrantor

Source

const NAME: &'static str = "mz_acl_item_grantor"

Source

impl FuncName for MzAclItemPrivileges

Source

const NAME: &'static str = "mz_acl_item_privileges"

Source

impl FuncName for MzFormatPrivileges

Source

const NAME: &'static str = "mz_format_privileges"

Source

impl FuncName for MzRenderTypmod

Source

const NAME: &'static str = "mz_render_typmod"

Source

impl FuncName for MzRowSize

Source

const NAME: &'static str = "mz_row_size"

Source

impl FuncName for MzTypeName

Source

const NAME: &'static str = "mz_type_name"

Source

impl FuncName for MzValidatePrivileges

Source

const NAME: &'static str = "mz_validate_privileges"

Source

impl FuncName for MzValidateRolePrivilege

Source

const NAME: &'static str = "mz_validate_role_privilege"

Source

impl FuncName for NegFloat32

Source

const NAME: &'static str = "neg_float32"

Source

impl FuncName for NegFloat64

Source

const NAME: &'static str = "neg_float64"

Source

impl FuncName for NegInt16

Source

const NAME: &'static str = "neg_int16"

Source

impl FuncName for NegInt32

Source

const NAME: &'static str = "neg_int32"

Source

impl FuncName for NegInt64

Source

const NAME: &'static str = "neg_int64"

Source

impl FuncName for NegInterval

Source

const NAME: &'static str = "neg_interval"

Source

impl FuncName for NegNumeric

Source

const NAME: &'static str = "neg_numeric"

Source

impl FuncName for Normalize

Source

const NAME: &'static str = "normalize"

Source

impl FuncName for Not

Source

const NAME: &'static str = "not"

Source

impl FuncName for NotEq

Source

const NAME: &'static str = "not_eq"

Source

impl FuncName for Or

Source

const NAME: &'static str = "or"

Source

impl FuncName for PadChar

Source

const NAME: &'static str = "pad_char"

Source

impl FuncName for PadLeading

Source

const NAME: &'static str = "pad_leading"

Source

impl FuncName for Panic

Source

const NAME: &'static str = "panic"

Source

impl FuncName for ParseCatalogAclMode

Source

const NAME: &'static str = "parse_catalog_acl_mode"

Source

impl FuncName for ParseCatalogAuditLogDetails

Source

const NAME: &'static str = "parse_catalog_audit_log_details"

Source

impl FuncName for ParseCatalogCreateSql

Source

const NAME: &'static str = "parse_catalog_create_sql"

Source

impl FuncName for ParseCatalogId

Source

const NAME: &'static str = "parse_catalog_id"

Source

impl FuncName for ParseCatalogPrivileges

Source

const NAME: &'static str = "parse_catalog_privileges"

Source

impl FuncName for ParseIdent

Source

const NAME: &'static str = "parse_ident"

Source

impl FuncName for ParseKafkaSourceDetails

Source

const NAME: &'static str = "parse_kafka_source_details"

Source

impl FuncName for ParsePostgresSourceDetails

Source

const NAME: &'static str = "parse_postgres_source_details"

Source

impl FuncName for PgColumnSize

Source

const NAME: &'static str = "pg_column_size"

Source

impl FuncName for PgSizePretty

Source

const NAME: &'static str = "pg_size_pretty"

Source

impl FuncName for Position

Source

const NAME: &'static str = "position"

Source

impl FuncName for Power

Source

const NAME: &'static str = "power"

Source

impl FuncName for PowerNumeric

Source

const NAME: &'static str = "power_numeric"

Source

impl FuncName for PrettySql

Source

const NAME: &'static str = "pretty_sql"

Source

impl FuncName for QuoteIdent

Source

const NAME: &'static str = "quote_ident"

Source

impl FuncName for Radians

Source

const NAME: &'static str = "radians"

Source

impl FuncName for RangeAdjacent

Source

const NAME: &'static str = "range_adjacent"

Source

impl FuncName for RangeAfter

Source

const NAME: &'static str = "range_after"

Source

impl FuncName for RangeBefore

Source

const NAME: &'static str = "range_before"

Source

impl FuncName for RangeContainsDate

Source

const NAME: &'static str = "range_contains_date"

Source

impl FuncName for RangeContainsDateRev

Source

const NAME: &'static str = "range_contains_date_rev"

Source

impl FuncName for RangeContainsI32

Source

const NAME: &'static str = "range_contains_i32"

Source

impl FuncName for RangeContainsI64

Source

const NAME: &'static str = "range_contains_i64"

Source

impl FuncName for RangeContainsI32Rev

Source

const NAME: &'static str = "range_contains_i32_rev"

Source

impl FuncName for RangeContainsI64Rev

Source

const NAME: &'static str = "range_contains_i64_rev"

Source

impl FuncName for RangeContainsNumeric

Source

const NAME: &'static str = "range_contains_numeric"

Source

impl FuncName for RangeContainsNumericRev

Source

const NAME: &'static str = "range_contains_numeric_rev"

Source

impl FuncName for RangeContainsRange

Source

const NAME: &'static str = "range_contains_range"

Source

impl FuncName for RangeContainsRangeRev

Source

const NAME: &'static str = "range_contains_range_rev"

Source

impl FuncName for RangeContainsTimestamp

Source

const NAME: &'static str = "range_contains_timestamp"

Source

impl FuncName for RangeContainsTimestampRev

Source

const NAME: &'static str = "range_contains_timestamp_rev"

Source

impl FuncName for RangeContainsTimestampTz

Source

const NAME: &'static str = "range_contains_timestamp_tz"

Source

impl FuncName for RangeContainsTimestampTzRev

Source

const NAME: &'static str = "range_contains_timestamp_tz_rev"

Source

impl FuncName for RangeCreate

Source

const NAME: &'static str = "range_create"

Source

impl FuncName for RangeDifference

Source

const NAME: &'static str = "range_difference"

Source

impl FuncName for RangeEmpty

Source

const NAME: &'static str = "range_empty"

Source

impl FuncName for RangeIntersection

Source

const NAME: &'static str = "range_intersection"

Source

impl FuncName for RangeLower

Source

const NAME: &'static str = "range_lower"

Source

impl FuncName for RangeLowerInc

Source

const NAME: &'static str = "range_lower_inc"

Source

impl FuncName for RangeLowerInf

Source

const NAME: &'static str = "range_lower_inf"

Source

impl FuncName for RangeOverlaps

Source

const NAME: &'static str = "range_overlaps"

Source

impl FuncName for RangeOverleft

Source

const NAME: &'static str = "range_overleft"

Source

impl FuncName for RangeOverright

Source

const NAME: &'static str = "range_overright"

Source

impl FuncName for RangeUnion

Source

const NAME: &'static str = "range_union"

Source

impl FuncName for RangeUpper

Source

const NAME: &'static str = "range_upper"

Source

impl FuncName for RangeUpperInc

Source

const NAME: &'static str = "range_upper_inc"

Source

impl FuncName for RangeUpperInf

Source

const NAME: &'static str = "range_upper_inf"

Source

impl FuncName for RecordCreate

Source

const NAME: &'static str = "record_create"

Source

impl FuncName for RecordGet

Source

const NAME: &'static str = "record_get"

Source

impl FuncName for RedactSql

Source

const NAME: &'static str = "redact_sql"

Source

impl FuncName for mz_expr::func::variadic::RegexpMatch

Source

const NAME: &'static str = "regexp_match"

Source

impl FuncName for mz_expr::func::RegexpMatch

Source

const NAME: &'static str = "regexp_match"

Source

impl FuncName for mz_expr::func::variadic::RegexpReplace

Source

const NAME: &'static str = "regexp_replace"

Source

impl FuncName for mz_expr::func::RegexpReplace

Source

const NAME: &'static str = "regexp_replace"

Source

impl FuncName for mz_expr::func::variadic::RegexpSplitToArray

Source

const NAME: &'static str = "regexp_split_to_array"

Source

impl FuncName for mz_expr::func::RegexpSplitToArray

Source

const NAME: &'static str = "regexp_split_to_array"

Source

impl FuncName for RepeatString

Source

const NAME: &'static str = "repeat_string"

Source

impl FuncName for Replace

Source

const NAME: &'static str = "replace"

Source

impl FuncName for Reverse

Source

const NAME: &'static str = "reverse"

Source

impl FuncName for Right

Source

const NAME: &'static str = "right"

Source

impl FuncName for RoundFloat32

Source

const NAME: &'static str = "round_float32"

Source

impl FuncName for RoundFloat64

Source

const NAME: &'static str = "round_float64"

Source

impl FuncName for RoundNumeric

Source

const NAME: &'static str = "round_numeric"

Source

impl FuncName for RoundNumericBinary

Source

const NAME: &'static str = "round_numeric_binary"

Source

impl FuncName for SeahashBytes

Source

const NAME: &'static str = "seahash_bytes"

Source

impl FuncName for SeahashString

Source

const NAME: &'static str = "seahash_string"

Source

impl FuncName for Sin

Source

const NAME: &'static str = "sin"

Source

impl FuncName for Sinh

Source

const NAME: &'static str = "sinh"

Source

impl FuncName for Sleep

Source

const NAME: &'static str = "sleep"

Source

impl FuncName for SplitPart

Source

const NAME: &'static str = "split_part"

Source

impl FuncName for SqrtFloat64

Source

const NAME: &'static str = "sqrt_float64"

Source

impl FuncName for SqrtNumeric

Source

const NAME: &'static str = "sqrt_numeric"

Source

impl FuncName for StartsWith

Source

const NAME: &'static str = "starts_with"

Source

impl FuncName for StepMzTimestamp

Source

const NAME: &'static str = "step_mz_timestamp"

Source

impl FuncName for StringToArray

Source

const NAME: &'static str = "string_to_array"

Source

impl FuncName for Strpos

Source

const NAME: &'static str = "strpos"

Source

impl FuncName for SubDate

Source

const NAME: &'static str = "sub_date"

Source

impl FuncName for SubDateInterval

Source

const NAME: &'static str = "sub_date_interval"

Source

impl FuncName for SubFloat32

Source

const NAME: &'static str = "sub_float32"

Source

impl FuncName for SubFloat64

Source

const NAME: &'static str = "sub_float64"

Source

impl FuncName for SubInt16

Source

const NAME: &'static str = "sub_int16"

Source

impl FuncName for SubInt32

Source

const NAME: &'static str = "sub_int32"

Source

impl FuncName for SubInt64

Source

const NAME: &'static str = "sub_int64"

Source

impl FuncName for SubInterval

Source

const NAME: &'static str = "sub_interval"

Source

impl FuncName for SubNumeric

Source

const NAME: &'static str = "sub_numeric"

Source

impl FuncName for SubTime

Source

const NAME: &'static str = "sub_time"

Source

impl FuncName for SubTimeInterval

Source

const NAME: &'static str = "sub_time_interval"

Source

impl FuncName for SubTimestamp

Source

const NAME: &'static str = "sub_timestamp"

Source

impl FuncName for SubTimestampInterval

Source

const NAME: &'static str = "sub_timestamp_interval"

Source

impl FuncName for SubTimestampTz

Source

const NAME: &'static str = "sub_timestamp_tz"

Source

impl FuncName for SubTimestampTzInterval

Source

const NAME: &'static str = "sub_timestamp_tz_interval"

Source

impl FuncName for SubUint16

Source

const NAME: &'static str = "sub_uint16"

Source

impl FuncName for SubUint32

Source

const NAME: &'static str = "sub_uint32"

Source

impl FuncName for SubUint64

Source

const NAME: &'static str = "sub_uint64"

Source

impl FuncName for Substr

Source

const NAME: &'static str = "substr"

Source

impl FuncName for Tan

Source

const NAME: &'static str = "tan"

Source

impl FuncName for Tanh

Source

const NAME: &'static str = "tanh"

Source

impl FuncName for TextConcatBinary

Source

const NAME: &'static str = "text_concat_binary"

Source

impl FuncName for TimezoneIntervalTimeBinary

Source

const NAME: &'static str = "timezone_interval_time_binary"

Source

impl FuncName for TimezoneIntervalTimestampBinary

Source

const NAME: &'static str = "timezone_interval_timestamp_binary"

Source

impl FuncName for TimezoneIntervalTimestampTzBinary

Source

const NAME: &'static str = "timezone_interval_timestamp_tz_binary"

Source

impl FuncName for TimezoneOffset

Source

const NAME: &'static str = "timezone_offset"

Source

impl FuncName for TimezoneTime

Source

const NAME: &'static str = "timezone_time"

Source

impl FuncName for TimezoneTimeVariadic

Source

const NAME: &'static str = "timezone_time_variadic"

Source

impl FuncName for TimezoneTimestamp

Source

const NAME: &'static str = "timezone_timestamp"

Source

impl FuncName for TimezoneTimestampBinary

Source

const NAME: &'static str = "timezone_timestamp_binary"

Source

impl FuncName for TimezoneTimestampTz

Source

const NAME: &'static str = "timezone_timestamp_tz"

Source

impl FuncName for TimezoneTimestampTzBinary

Source

const NAME: &'static str = "timezone_timestamp_tz_binary"

Source

impl FuncName for ToCharTimestamp

Source

const NAME: &'static str = "to_char_timestamp"

Source

impl FuncName for ToCharTimestampFormat

Source

const NAME: &'static str = "to_char_timestamp_format"

Source

impl FuncName for ToCharTimestampTz

Source

const NAME: &'static str = "to_char_timestamp_tz"

Source

impl FuncName for ToCharTimestampTzFormat

Source

const NAME: &'static str = "to_char_timestamp_tz_format"

Source

impl FuncName for ToTimestamp

Source

const NAME: &'static str = "to_timestamp"

Source

impl FuncName for Translate

Source

const NAME: &'static str = "translate"

Source

impl FuncName for Trim

Source

const NAME: &'static str = "trim"

Source

impl FuncName for TrimLeading

Source

const NAME: &'static str = "trim_leading"

Source

impl FuncName for TrimLeadingWhitespace

Source

const NAME: &'static str = "trim_leading_whitespace"

Source

impl FuncName for TrimTrailing

Source

const NAME: &'static str = "trim_trailing"

Source

impl FuncName for TrimTrailingWhitespace

Source

const NAME: &'static str = "trim_trailing_whitespace"

Source

impl FuncName for TrimWhitespace

Source

const NAME: &'static str = "trim_whitespace"

Source

impl FuncName for TruncFloat32

Source

const NAME: &'static str = "trunc_float32"

Source

impl FuncName for TruncFloat64

Source

const NAME: &'static str = "trunc_float64"

Source

impl FuncName for TruncNumeric

Source

const NAME: &'static str = "trunc_numeric"

Source

impl FuncName for TryParseMonotonicIso8601Timestamp

Source

const NAME: &'static str = "try_parse_monotonic_iso8601_timestamp"

Source

impl FuncName for Upper

Source

const NAME: &'static str = "upper"

Source

impl FuncName for UuidGenerateV5

Source

const NAME: &'static str = "uuid_generate_v5"