fn simplify_coalesce(e: &mut MirScalarExpr, column_types: &[ReprColumnType])Expand description
Simplifies a Coalesce:
- If all arguments are null, the result is null.
- Drop null arguments (none of them can be the result).
- Truncate after the first argument known to be non-null (a literal or a non-nullable column).
- Deduplicate arguments (e.g.
coalesce(#0, #0) → coalesce(#0)). - Unwrap a single-argument
coalesce.